SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL';

CREATE SCHEMA IF NOT EXISTS `Weather` DEFAULT CHARACTER SET utf8 COLLATE utf8_unicode_ci ;
USE `Weather` ;

-- -----------------------------------------------------
-- Table `Weather`.`Location`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`Location` (
  `vpID` TINYINT(3) UNSIGNED NOT NULL ,
  `Model` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  `SN` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  `Description` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  `Address` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  `City` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  `County` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  `State` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  `Country` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  `Longitude` DECIMAL(12,6) NULL DEFAULT NULL ,
  `Latitude` DECIMAL(12,6) NULL DEFAULT NULL ,
  `Contact` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  `InsertTS` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
  PRIMARY KEY (`vpID`) )
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`YMD`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`YMD` (
  `vpID` TINYINT(3) UNSIGNED NOT NULL DEFAULT '0' ,
  `YearMonthDay` INT(8) UNSIGNED NOT NULL ,
  `YearMonth` INT(6) UNSIGNED NOT NULL ,
  `bDate` DATE NOT NULL ,
  `bYear` SMALLINT(4) UNSIGNED NOT NULL ,
  `bMonth` TINYINT(2) UNSIGNED ZEROFILL NOT NULL ,
  `bDay` TINYINT(2) UNSIGNED ZEROFILL NOT NULL ,
  `DayName` CHAR(9) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  `Sunrise` TIME NULL DEFAULT NULL ,
  `Sunset` TIME NULL DEFAULT NULL ,
  `SolarNoon` TIME NULL DEFAULT NULL ,
  PRIMARY KEY (`YearMonthDay`, `vpID`) ,
  INDEX `bDate` (`bDate` ASC) ,
  INDEX `fk_YMD_Location1` (`vpID` ASC) ,
  CONSTRAINT `fk_YMD_Location1`
    FOREIGN KEY (`vpID` )
    REFERENCES `Weather`.`Location` (`vpID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`IndexDT`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`IndexDT` (
  `RecID` BIGINT(20) UNSIGNED NOT NULL AUTO_INCREMENT ,
  `vpID` TINYINT(3) UNSIGNED NOT NULL DEFAULT '0' ,
  `rtCaptureTime` DATETIME NULL DEFAULT NULL ,
  `wxCaptureTime` DATETIME NULL DEFAULT NULL ,
  `rtTT` BIGINT(20) UNSIGNED NULL DEFAULT NULL ,
  `wxTT` BIGINT(20) UNSIGNED NULL DEFAULT NULL ,
  `bTT` BIGINT(20) UNSIGNED NULL DEFAULT NULL ,
  `sTT` BIGINT(20) UNSIGNED NULL DEFAULT NULL ,
  `eTT` BIGINT(20) UNSIGNED NULL DEFAULT NULL ,
  `rt` INT UNSIGNED NULL DEFAULT NULL ,
  `vpIDorgRecID` BIGINT(20) UNSIGNED NULL DEFAULT NULL ,
  PRIMARY KEY (`RecID`, `vpID`) ,
  INDEX `rtCaptureTime` (`rtCaptureTime` ASC) ,
  INDEX `wxCaptureTime` (`wxCaptureTime` ASC) ,
  INDEX `rtTT` (`rtTT` ASC) ,
  INDEX `wxTT` (`wxTT` ASC) ,
  INDEX `vpIDorgRecID` (`vpID` ASC, `vpIDorgRecID` ASC) ,
  INDEX `bTT` (`bTT` ASC) ,
  INDEX `sTT` (`sTT` ASC) ,
  INDEX `fk_IndexDT_Location1` (`vpID` ASC) ,
  CONSTRAINT `fk_IndexDT_Location1`
    FOREIGN KEY (`vpID` )
    REFERENCES `Weather`.`Location` (`vpID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
AUTO_INCREMENT = 0
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`DT`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`DT` (
  `bDateTime` DATETIME NOT NULL ,
  `DST` TINYINT(1) NOT NULL ,
  `RecID` BIGINT(20) UNSIGNED NOT NULL ,
  `vpID` TINYINT(3) UNSIGNED NOT NULL DEFAULT '0' ,
  `YearMonthDay` INT(8) UNSIGNED NOT NULL ,
  `YearMonth` INT(6) UNSIGNED NOT NULL ,
  `bDate` DATE NOT NULL ,
  `bTime` TIME NOT NULL ,
  `HHMM` VARCHAR(5) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  `bYear` SMALLINT(4) UNSIGNED NOT NULL ,
  `bMonth` TINYINT(2) UNSIGNED ZEROFILL NOT NULL ,
  `bDay` TINYINT(2) UNSIGNED ZEROFILL NOT NULL ,
  `bHour` TINYINT(2) UNSIGNED ZEROFILL NOT NULL ,
  `bMinute` TINYINT(2) UNSIGNED ZEROFILL NOT NULL ,
  `bSecond` TINYINT(2) UNSIGNED ZEROFILL NOT NULL ,
  `bTenths` TINYINT(2) UNSIGNED ZEROFILL NOT NULL ,
  `bTT` BIGINT(20) UNSIGNED NOT NULL ,
  `vpIDorgRecID` BIGINT(20) UNSIGNED NULL DEFAULT NULL ,
  `InsertTS` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
  PRIMARY KEY (`bDateTime`, `DST`, `vpID`) ,
  UNIQUE INDEX `RecID` (`RecID` ASC) ,
  INDEX `HHMM` (`HHMM` ASC) ,
  INDEX `YearMonthDay` (`YearMonthDay` ASC) ,
  INDEX `bTT` (`bTT` ASC) ,
  INDEX `bDate` (`bDate` ASC) ,
  INDEX `bTime` (`bTime` ASC) ,
  INDEX `RecIDvpID` (`RecID` ASC, `vpID` ASC) ,
  INDEX `vpIDorgRecID` (`vpID` ASC, `vpIDorgRecID` ASC) ,
  INDEX `vpID` (`vpID` ASC) ,
  INDEX `bDateTime` (`bDateTime` ASC) ,
  CONSTRAINT `fk_DT_Location1`
    FOREIGN KEY (`vpID` )
    REFERENCES `Weather`.`Location` (`vpID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_DT_YMD1`
    FOREIGN KEY (`YearMonthDay` )
    REFERENCES `Weather`.`YMD` (`YearMonthDay` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_DT_IndexDT2`
    FOREIGN KEY (`bTT` )
    REFERENCES `Weather`.`IndexDT` (`bTT` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_DT_IndexDT1`
    FOREIGN KEY (`RecID` )
    REFERENCES `Weather`.`IndexDT` (`RecID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`Avg10Min`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`Avg10Min` (
  `RecID` BIGINT(20) UNSIGNED NOT NULL ,
  `LastID` BIGINT(20) UNSIGNED NULL DEFAULT NULL ,
  `Last10MinPtr` TINYINT(2) UNSIGNED NULL DEFAULT NULL ,
  `Cur10MinPtr` TINYINT(2) UNSIGNED NULL DEFAULT NULL ,
  `WindPseudoCurPtr` TINYINT(1) NULL DEFAULT NULL ,
  `WindSpeedRpt` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `WindSpeedCalc` DECIMAL(6,2) NULL DEFAULT NULL ,
  PRIMARY KEY (`RecID`) ,
  INDEX `Avg10Min_FKIndex1` (`RecID` ASC) ,
  CONSTRAINT `fk_Avg10Min_DT1`
    FOREIGN KEY (`RecID` )
    REFERENCES `Weather`.`DT` (`RecID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`Avg15Min`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`Avg15Min` (
  `RecID` BIGINT(20) UNSIGNED NOT NULL ,
  `LastID` BIGINT(20) UNSIGNED NULL DEFAULT NULL ,
  `Last15MinPtr` TINYINT(2) UNSIGNED NULL DEFAULT NULL ,
  `Cur15MinPtr` TINYINT(2) UNSIGNED NULL DEFAULT NULL ,
  `BaroPseudoCurPtr` TINYINT(1) NULL DEFAULT NULL ,
  `BaroPressureRpt` DECIMAL(8,3) NULL DEFAULT NULL ,
  `BaroPressureCalc` DECIMAL(8,3) NULL DEFAULT NULL ,
  `RainPseudoCurPtr` TINYINT(1) NULL DEFAULT NULL ,
  `RainAmountRpt` DECIMAL(6,2) NULL DEFAULT NULL ,
  `RainAmountCalc` DECIMAL(6,2) NULL DEFAULT NULL ,
  PRIMARY KEY (`RecID`) ,
  INDEX `Avg15Min_FKIndex1` (`RecID` ASC) ,
  CONSTRAINT `fk_Avg15Min_DT1`
    FOREIGN KEY (`RecID` )
    REFERENCES `Weather`.`DT` (`RecID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`Barometer`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`Barometer` (
  `RecID` BIGINT(20) UNSIGNED NOT NULL ,
  `Pressure` DECIMAL(8,3) NULL DEFAULT NULL ,
  `Trend` VARCHAR(20) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  `TrendImage` VARCHAR(10) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  `F` CHAR(1) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL ,
  PRIMARY KEY (`RecID`) ,
  INDEX `Barometer_FKIndex1` (`RecID` ASC) ,
  CONSTRAINT `fk_Barometer_DT1`
    FOREIGN KEY (`RecID` )
    REFERENCES `Weather`.`DT` (`RecID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`YHL`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`YHL` (
  `vpID` TINYINT(3) UNSIGNED NOT NULL DEFAULT '0' ,
  `bYear` SMALLINT(4) UNSIGNED NOT NULL ,
  `InTempHigh` DECIMAL(6,1) NULL DEFAULT NULL ,
  `InTempLow` DECIMAL(6,1) NULL DEFAULT NULL ,
  `OutTempHigh` DECIMAL(6,1) NULL DEFAULT NULL ,
  `OutTempLow` DECIMAL(6,1) NULL DEFAULT NULL ,
  `InHumHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `InHumLow` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `OutHumHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `OutHumLow` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `WindSpeedHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `WindSpeedLow` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `BarometerHigh` DECIMAL(8,3) NULL DEFAULT NULL ,
  `BarometerLow` DECIMAL(8,3) NULL DEFAULT NULL ,
  `TotalRain` DECIMAL(8,2) NULL DEFAULT NULL ,
  `RainDayTotal` DECIMAL(7,2) NULL DEFAULT NULL ,
  `RainRateHigh` DECIMAL(7,2) NULL DEFAULT NULL ,
  `WindChillLow` DECIMAL(6,1) NULL DEFAULT NULL ,
  `HeatIndexHigh` DECIMAL(6,1) NULL DEFAULT NULL ,
  `SolarRadHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `UVHigh` SMALLINT(5) NULL DEFAULT NULL ,
  `TotalET` DECIMAL(8,3) NULL DEFAULT NULL ,
  `ETDayTotal` DECIMAL(6,3) NULL DEFAULT NULL ,
  `DewPointHigh` SMALLINT(6) NULL DEFAULT NULL ,
  `DewPointLow` SMALLINT(6) NULL DEFAULT NULL ,
  `THSWHigh` SMALLINT(6) NULL DEFAULT NULL ,
  `InTempHighDT` DATETIME NULL DEFAULT NULL ,
  `InTempLowDT` DATETIME NULL DEFAULT NULL ,
  `OutTempHighDT` DATETIME NULL DEFAULT NULL ,
  `OutTempLowDT` DATETIME NULL DEFAULT NULL ,
  `InHumHighDT` DATETIME NULL DEFAULT NULL ,
  `InHumLowDT` DATETIME NULL DEFAULT NULL ,
  `OutHumHighDT` DATETIME NULL DEFAULT NULL ,
  `OutHumLowDT` DATETIME NULL DEFAULT NULL ,
  `WindSpeedHighDT` DATETIME NULL DEFAULT NULL ,
  `WindSpeedLowDT` DATETIME NULL DEFAULT NULL ,
  `BarometerHighDT` DATETIME NULL DEFAULT NULL ,
  `BarometerLowDT` DATETIME NULL DEFAULT NULL ,
  `RainDayTotalDT` DATETIME NULL DEFAULT NULL ,
  `RainRateHighDT` DATETIME NULL DEFAULT NULL ,
  `WindChillLowDT` DATETIME NULL DEFAULT NULL ,
  `HeatIndexHighDT` DATETIME NULL DEFAULT NULL ,
  `SolarRadHighDT` DATETIME NULL DEFAULT NULL ,
  `UVHighDT` DATETIME NULL DEFAULT NULL ,
  `ETDayTotalDT` DATETIME NULL DEFAULT NULL ,
  `DewPointHighDT` DATETIME NULL DEFAULT NULL ,
  `DewPointLowDT` DATETIME NULL DEFAULT NULL ,
  `THSWHighDT` DATETIME NULL DEFAULT NULL ,
  `HourlyTHSWIndex` SMALLINT(6) NULL DEFAULT NULL ,
  `HourlyDewPointHigh` SMALLINT(6) NULL DEFAULT NULL ,
  `HourlyDewPointLow` SMALLINT(6) NULL DEFAULT NULL ,
  `HourlyETHigh` DECIMAL(6,3) NULL DEFAULT NULL ,
  `HourlyTotalET` DECIMAL(6,3) NULL DEFAULT NULL ,
  `HourlyTHSWIndexDT` DATETIME NULL DEFAULT NULL ,
  `HourlyDewPointHighDT` DATETIME NULL DEFAULT NULL ,
  `HourlyDewPointLowDT` DATETIME NULL DEFAULT NULL ,
  `HourlyETHighDT` DATETIME NULL DEFAULT NULL ,
  `F` CHAR(1) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL ,
  `UpdateTS` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
  PRIMARY KEY (`bYear`, `vpID`) ,
  INDEX `fk_YHL_Location1` (`vpID` ASC) ,
  CONSTRAINT `fk_YHL_Location1`
    FOREIGN KEY (`vpID` )
    REFERENCES `Weather`.`Location` (`vpID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`MHL`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`MHL` (
  `vpID` TINYINT(3) UNSIGNED NOT NULL DEFAULT '0' ,
  `YearMonth` INT(6) UNSIGNED NOT NULL ,
  `bYear` SMALLINT(4) UNSIGNED NOT NULL ,
  `bMonth` TINYINT(2) UNSIGNED ZEROFILL NOT NULL ,
  `InTempHigh` DECIMAL(6,1) NULL DEFAULT NULL ,
  `InTempLow` DECIMAL(6,1) NULL DEFAULT NULL ,
  `OutTempHigh` DECIMAL(6,1) NULL DEFAULT NULL ,
  `OutTempLow` DECIMAL(6,1) NULL DEFAULT NULL ,
  `InHumHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `InHumLow` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `OutHumHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `OutHumLow` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `WindSpeedHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `WindSpeedLow` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `BarometerHigh` DECIMAL(8,3) NULL DEFAULT NULL ,
  `BarometerLow` DECIMAL(8,3) NULL DEFAULT NULL ,
  `TotalRain` DECIMAL(8,2) NULL DEFAULT NULL ,
  `RainDayTotal` DECIMAL(7,2) NULL DEFAULT NULL ,
  `RainRateHigh` DECIMAL(7,2) NULL DEFAULT NULL ,
  `WindChillLow` DECIMAL(6,1) NULL DEFAULT NULL ,
  `HeatIndexHigh` DECIMAL(6,1) NULL DEFAULT NULL ,
  `SolarRadHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `UVHigh` SMALLINT(5) NULL DEFAULT NULL ,
  `TotalET` DECIMAL(8,3) NULL DEFAULT NULL ,
  `ETDayTotal` DECIMAL(6,3) NULL DEFAULT NULL ,
  `DewPointHigh` SMALLINT(6) NULL DEFAULT NULL ,
  `DewPointLow` SMALLINT(6) NULL DEFAULT NULL ,
  `THSWHigh` SMALLINT(6) NULL DEFAULT NULL ,
  `InTempHighDT` DATETIME NULL DEFAULT NULL ,
  `InTempLowDT` DATETIME NULL DEFAULT NULL ,
  `OutTempHighDT` DATETIME NULL DEFAULT NULL ,
  `OutTempLowDT` DATETIME NULL DEFAULT NULL ,
  `InHumHighDT` DATETIME NULL DEFAULT NULL ,
  `InHumLowDT` DATETIME NULL DEFAULT NULL ,
  `OutHumHighDT` DATETIME NULL DEFAULT NULL ,
  `OutHumLowDT` DATETIME NULL DEFAULT NULL ,
  `WindSpeedHighDT` DATETIME NULL DEFAULT NULL ,
  `WindSpeedLowDT` DATETIME NULL DEFAULT NULL ,
  `BarometerHighDT` DATETIME NULL DEFAULT NULL ,
  `BarometerLowDT` DATETIME NULL DEFAULT NULL ,
  `RainDayTotalDT` DATETIME NULL DEFAULT NULL ,
  `RainRateHighDT` DATETIME NULL DEFAULT NULL ,
  `WindChillLowDT` DATETIME NULL DEFAULT NULL ,
  `HeatIndexHighDT` DATETIME NULL DEFAULT NULL ,
  `SolarRadHighDT` DATETIME NULL DEFAULT NULL ,
  `UVHighDT` DATETIME NULL DEFAULT NULL ,
  `ETDayTotalDT` DATETIME NULL DEFAULT NULL ,
  `DewPointHighDT` DATETIME NULL DEFAULT NULL ,
  `DewPointLowDT` DATETIME NULL DEFAULT NULL ,
  `THSWHighDT` DATETIME NULL DEFAULT NULL ,
  `HourlyTHSWIndex` SMALLINT(6) NULL DEFAULT NULL ,
  `HourlyDewPointHigh` SMALLINT(6) NULL DEFAULT NULL ,
  `HourlyDewPointLow` SMALLINT(6) NULL DEFAULT NULL ,
  `HourlyETHigh` DECIMAL(6,3) NULL DEFAULT NULL ,
  `HourlyTotalET` DECIMAL(6,3) NULL DEFAULT NULL ,
  `HourlyTHSWIndexDT` DATETIME NULL DEFAULT NULL ,
  `HourlyDewPointHighDT` DATETIME NULL DEFAULT NULL ,
  `HourlyDewPointLowDT` DATETIME NULL DEFAULT NULL ,
  `HourlyETHighDT` DATETIME NULL DEFAULT NULL ,
  `F` CHAR(1) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL ,
  `UpdateTS` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
  PRIMARY KEY (`YearMonth`, `vpID`) ,
  INDEX `bYear` (`bYear` ASC) ,
  INDEX `YvpID` (`vpID` ASC, `bYear` ASC) ,
  INDEX `fk_MHL_Location1` (`vpID` ASC) ,
  CONSTRAINT `fk_MHL_YHL1`
    FOREIGN KEY (`bYear` )
    REFERENCES `Weather`.`YHL` (`bYear` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_MHL_Location1`
    FOREIGN KEY (`vpID` )
    REFERENCES `Weather`.`Location` (`vpID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`DHL`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`DHL` (
  `vpID` TINYINT(3) UNSIGNED NOT NULL DEFAULT '0' ,
  `YearMonthDay` INT(8) UNSIGNED NOT NULL ,
  `YearMonth` INT(6) UNSIGNED NOT NULL ,
  `bDate` DATE NOT NULL ,
  `bYear` SMALLINT(4) UNSIGNED NOT NULL ,
  `bMonth` SMALLINT(2) UNSIGNED ZEROFILL NOT NULL ,
  `bDay` SMALLINT(2) UNSIGNED ZEROFILL NOT NULL ,
  `InTempHigh` DECIMAL(6,1) NULL DEFAULT NULL ,
  `InTempLow` DECIMAL(6,1) NULL DEFAULT NULL ,
  `OutTempHigh` DECIMAL(6,1) NULL DEFAULT NULL ,
  `OutTempLow` DECIMAL(6,1) NULL DEFAULT NULL ,
  `InHumHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `InHumLow` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `OutHumHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `OutHumLow` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `WindSpeedHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `WindSpeedLow` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `BarometerHigh` DECIMAL(8,3) NULL DEFAULT NULL ,
  `BarometerLow` DECIMAL(8,3) NULL DEFAULT NULL ,
  `TotalRain` DECIMAL(8,2) NULL DEFAULT NULL ,
  `RainDayTotal` DECIMAL(7,2) NULL DEFAULT NULL ,
  `RainRateHigh` DECIMAL(7,2) NULL DEFAULT NULL ,
  `WindChillLow` DECIMAL(6,1) NULL DEFAULT NULL ,
  `HeatIndexHigh` DECIMAL(6,1) NULL DEFAULT NULL ,
  `SolarRadHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `UVHigh` SMALLINT(5) NULL DEFAULT NULL ,
  `TotalET` DECIMAL(8,3) NULL DEFAULT NULL ,
  `ETDayTotal` DECIMAL(6,3) NULL DEFAULT NULL ,
  `DewPointHigh` SMALLINT(6) NULL DEFAULT NULL ,
  `DewPointLow` SMALLINT(6) NULL DEFAULT NULL ,
  `THSWHigh` SMALLINT(6) NULL DEFAULT NULL ,
  `InTempHighDT` DATETIME NULL DEFAULT NULL ,
  `InTempLowDT` DATETIME NULL DEFAULT NULL ,
  `OutTempHighDT` DATETIME NULL DEFAULT NULL ,
  `OutTempLowDT` DATETIME NULL DEFAULT NULL ,
  `InHumHighDT` DATETIME NULL DEFAULT NULL ,
  `InHumLowDT` DATETIME NULL DEFAULT NULL ,
  `OutHumHighDT` DATETIME NULL DEFAULT NULL ,
  `OutHumLowDT` DATETIME NULL DEFAULT NULL ,
  `WindSpeedHighDT` DATETIME NULL DEFAULT NULL ,
  `WindSpeedLowDT` DATETIME NULL DEFAULT NULL ,
  `BarometerHighDT` DATETIME NULL DEFAULT NULL ,
  `BarometerLowDT` DATETIME NULL DEFAULT NULL ,
  `RainDayTotalDT` DATETIME NULL DEFAULT NULL ,
  `RainRateHighDT` DATETIME NULL DEFAULT NULL ,
  `WindChillLowDT` DATETIME NULL DEFAULT NULL ,
  `HeatIndexHighDT` DATETIME NULL DEFAULT NULL ,
  `SolarRadHighDT` DATETIME NULL DEFAULT NULL ,
  `UVHighDT` DATETIME NULL DEFAULT NULL ,
  `ETDayTotalDT` DATETIME NULL DEFAULT NULL ,
  `DewPointHighDT` DATETIME NULL DEFAULT NULL ,
  `DewPointLowDT` DATETIME NULL DEFAULT NULL ,
  `THSWHighDT` DATETIME NULL DEFAULT NULL ,
  `HourlyTHSWIndex` SMALLINT(6) NULL DEFAULT NULL ,
  `HourlyDewPointHigh` SMALLINT(6) NULL DEFAULT NULL ,
  `HourlyDewPointLow` SMALLINT(6) NULL DEFAULT NULL ,
  `HourlyOutTempHigh` SMALLINT(6) NULL DEFAULT NULL ,
  `HourlyOutTempLow` SMALLINT(6) NULL DEFAULT NULL ,
  `HourlyInTempHigh` SMALLINT(6) NULL DEFAULT NULL ,
  `HourlyInTempLow` SMALLINT(6) NULL DEFAULT NULL ,
  `HourlyOutHumHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `HourlyOutHumLow` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `HourlyInHumHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `HourlyInHumLow` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `HourlyWindSpeedAvg` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `HourlyWindDirAvg` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `HourlyWindSpeedHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `HourlyBarometerHigh` DECIMAL(8,3) NULL DEFAULT NULL ,
  `HourlyBarometerLow` DECIMAL(8,3) NULL DEFAULT NULL ,
  `HourlyRainAmount` DECIMAL(7,2) NULL DEFAULT NULL ,
  `HourlyRainRate` DECIMAL(7,2) NULL DEFAULT NULL ,
  `HourlyWindChill` SMALLINT(6) NULL DEFAULT NULL ,
  `HourlyHeatIndex` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `HourlySolarRad` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `HourlyETHigh` DECIMAL(6,3) NULL DEFAULT NULL ,
  `HourlyTotalET` DECIMAL(6,3) NULL DEFAULT NULL ,
  `HourlyTHSWIndexDT` DATETIME NULL DEFAULT NULL ,
  `HourlyDewPointHighDT` DATETIME NULL DEFAULT NULL ,
  `HourlyDewPointLowDT` DATETIME NULL DEFAULT NULL ,
  `HourlyOutTempHighDT` DATETIME NULL DEFAULT NULL ,
  `HourlyOutTempLowDT` DATETIME NULL DEFAULT NULL ,
  `HourlyInTempHighDT` DATETIME NULL DEFAULT NULL ,
  `HourlyInTempLowDT` DATETIME NULL DEFAULT NULL ,
  `HourlyOutHumHighDT` DATETIME NULL DEFAULT NULL ,
  `HourlyOutHumLowDT` DATETIME NULL DEFAULT NULL ,
  `HourlyInHumHighDT` DATETIME NULL DEFAULT NULL ,
  `HourlyInHumLowDT` DATETIME NULL DEFAULT NULL ,
  `HourlyWindSpeedAvgDT` DATETIME NULL DEFAULT NULL ,
  `HourlyWindDirAvgDT` DATETIME NULL DEFAULT NULL ,
  `HourlyWindSpeedHighDT` DATETIME NULL DEFAULT NULL ,
  `HourlyBarometerHighDT` DATETIME NULL DEFAULT NULL ,
  `HourlyBarometerLowDT` DATETIME NULL DEFAULT NULL ,
  `HourlyRainAmountDT` DATETIME NULL DEFAULT NULL ,
  `HourlyRainRateDT` DATETIME NULL DEFAULT NULL ,
  `HourlyWindChillDT` DATETIME NULL DEFAULT NULL ,
  `HourlyHeatIndexDT` DATETIME NULL DEFAULT NULL ,
  `HourlySolarRadDT` DATETIME NULL DEFAULT NULL ,
  `HourlyETHighDT` DATETIME NULL DEFAULT NULL ,
  `F` CHAR(1) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL ,
  `UpdateTS` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
  PRIMARY KEY (`YearMonthDay`, `vpID`) ,
  INDEX `YearMonth` (`YearMonth` ASC) ,
  INDEX `bDate` (`bDate` ASC) ,
  INDEX `YMvpID` (`YearMonth` ASC, `vpID` ASC) ,
  INDEX `fk_DHL_YMD1` (`YearMonthDay` ASC) ,
  INDEX `fk_DHL_Location1` (`vpID` ASC) ,
  CONSTRAINT `fk_DHL_YMD1`
    FOREIGN KEY (`YearMonthDay` )
    REFERENCES `Weather`.`YMD` (`YearMonthDay` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_DHL_Location1`
    FOREIGN KEY (`vpID` )
    REFERENCES `Weather`.`Location` (`vpID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_DHL_MHL2`
    FOREIGN KEY (`YearMonth` )
    REFERENCES `Weather`.`MHL` (`YearMonth` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`Forecasts`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`Forecasts` (
  `ForecastRuleNumber` SMALLINT(5) UNSIGNED NOT NULL ,
  `Description` TEXT CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  PRIMARY KEY (`ForecastRuleNumber`) )
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`Hourly`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`Hourly` (
  `RecID` BIGINT(20) UNSIGNED NOT NULL ,
  `ForecastRuleNumber` SMALLINT(5) UNSIGNED NOT NULL ,
  `ForecastIconNumber` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `OutTemp` SMALLINT(6) NULL DEFAULT NULL ,
  `InTemp` SMALLINT(6) NULL DEFAULT NULL ,
  `OutHum` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `InHum` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `WindSpeedAvg` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `WindDirAvg` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `WindSpeedHigh` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `Barometer` DECIMAL(8,3) NULL DEFAULT NULL ,
  `RainAmount` DECIMAL(7,2) NULL DEFAULT NULL ,
  `RainRate` DECIMAL(7,2) NULL DEFAULT NULL ,
  `WindChill` SMALLINT(6) NULL DEFAULT NULL ,
  `HeatIndex` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `THSWIndex` SMALLINT(6) NULL DEFAULT NULL ,
  `DewPoint` SMALLINT(6) NULL DEFAULT NULL ,
  `SolarRadAvg` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `ET` DECIMAL(6,3) NULL DEFAULT NULL ,
  `F` CHAR(1) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL ,
  PRIMARY KEY (`RecID`) ,
  INDEX `HourlyOnly_FKIndex1` (`RecID` ASC) ,
  INDEX `HourlyOnly_FKIndex2` (`ForecastRuleNumber` ASC) ,
  CONSTRAINT `fk_Hourly_DT1`
    FOREIGN KEY (`RecID` )
    REFERENCES `Weather`.`DT` (`RecID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Hourly_Forecasts1`
    FOREIGN KEY (`ForecastRuleNumber` )
    REFERENCES `Weather`.`Forecasts` (`ForecastRuleNumber` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`Humidity`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`Humidity` (
  `RecID` BIGINT(20) UNSIGNED NOT NULL ,
  `Indoor` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `Outdoor` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  PRIMARY KEY (`RecID`) ,
  INDEX `Humidity_FKIndex1` (`RecID` ASC) ,
  CONSTRAINT `fk_Humidity_DT1`
    FOREIGN KEY (`RecID` )
    REFERENCES `Weather`.`DT` (`RecID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`MinPtrData`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`MinPtrData` (
  `vpID` TINYINT(3) UNSIGNED NOT NULL DEFAULT '0' ,
  `RecID` BIGINT(20) UNSIGNED NULL DEFAULT NULL ,
  `bDateTime` DATETIME NOT NULL ,
  `bMinute` TINYINT(2) UNSIGNED ZEROFILL NULL DEFAULT NULL ,
  `time_t` INT(10) UNSIGNED NULL DEFAULT NULL ,
  `Last` TINYINT(1) NOT NULL DEFAULT '0' ,
  `Ptr` TINYINT(3) UNSIGNED NULL DEFAULT NULL ,
  `Item` VARCHAR(20) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL ,
  `Save` TINYINT(1) NOT NULL DEFAULT '0' ,
  `ItemData` VARCHAR(300) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  INDEX `bDateTime` (`bDateTime` ASC) ,
  INDEX `RecID` (`RecID` ASC) ,
  INDEX `Item` (`Item` ASC) ,
  INDEX `Save` (`Save` ASC) ,
  INDEX `Last` (`Last` ASC) ,
  INDEX `fk_MinPtrData_Location1` (`vpID` ASC) ,
  CONSTRAINT `fk_MinPtrData_DT1`
    FOREIGN KEY (`bDateTime` )
    REFERENCES `Weather`.`DT` (`bDateTime` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_MinPtrData_Location1`
    FOREIGN KEY (`vpID` )
    REFERENCES `Weather`.`Location` (`vpID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`Rain`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`Rain` (
  `RecID` BIGINT(20) UNSIGNED NOT NULL ,
  `StormStartedDate` DATE NULL DEFAULT NULL ,
  `CurrentlyRaining` TINYINT(1) NULL DEFAULT NULL ,
  `IncrementalRain` DECIMAL(7,2) NULL DEFAULT NULL ,
  `PerMinute` DECIMAL(8,3) NULL DEFAULT NULL ,
  `DayAmount` DECIMAL(7,2) NULL DEFAULT NULL ,
  `StormAmount` DECIMAL(7,2) NULL DEFAULT NULL ,
  `Rate` DECIMAL(7,2) NULL DEFAULT NULL ,
  `ET` DECIMAL(7,3) NULL DEFAULT NULL ,
  `F` CHAR(1) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL ,
  PRIMARY KEY (`RecID`) ,
  INDEX `Rain_FKIndex1` (`RecID` ASC) ,
  INDEX `StormStartedDate` (`StormStartedDate` ASC) ,
  INDEX `StormAmount` (`StormAmount` ASC) ,
  CONSTRAINT `fk_Rain_DT1`
    FOREIGN KEY (`RecID` )
    REFERENCES `Weather`.`DT` (`RecID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`Solar`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`Solar` (
  `RecID` BIGINT(20) UNSIGNED NOT NULL ,
  `Radiation` SMALLINT(5) NULL DEFAULT NULL ,
  `MinutesRad` DECIMAL(7,2) NULL DEFAULT NULL ,
  `UV` SMALLINT(5) NULL DEFAULT NULL ,
  `MinutesUV` DECIMAL(7,2) NULL DEFAULT NULL ,
  PRIMARY KEY (`RecID`) ,
  INDEX `SolarRadiation_FKIndex1` (`RecID` ASC) ,
  CONSTRAINT `fk_Solar_DT1`
    FOREIGN KEY (`RecID` )
    REFERENCES `Weather`.`DT` (`RecID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`Storms`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`Storms` (
  `vpID` TINYINT(3) UNSIGNED NOT NULL DEFAULT '0' ,
  `StormStartedDate` DATE NOT NULL ,
  `StormStartedTime` TIME NULL DEFAULT NULL ,
  `StormEndedDate` DATE NULL DEFAULT NULL ,
  `StormEndedTime` TIME NULL DEFAULT NULL ,
  `StormAmount` DECIMAL(7,2) NULL DEFAULT NULL ,
  `HighestRate` DECIMAL(7,2) NULL DEFAULT NULL ,
  `HighestRateDT` DATETIME NULL DEFAULT NULL ,
  `F` CHAR(1) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL ,
  PRIMARY KEY (`StormStartedDate`, `vpID`) ,
  INDEX `StormStartedTime` (`StormStartedTime` ASC) ,
  INDEX `StormEndedDate` (`StormEndedDate` ASC) ,
  INDEX `StormEndedTime` (`StormEndedTime` ASC) ,
  INDEX `fk_Storms_Location1` (`vpID` ASC) ,
  INDEX `fk_Storms_Rain1` (`StormStartedDate` ASC) ,
  CONSTRAINT `fk_Storms_Location1`
    FOREIGN KEY (`vpID` )
    REFERENCES `Weather`.`Location` (`vpID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION,
  CONSTRAINT `fk_Storms_Rain1`
    FOREIGN KEY (`StormStartedDate` )
    REFERENCES `Weather`.`Rain` (`StormStartedDate` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`Temperature`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`Temperature` (
  `RecID` BIGINT(20) UNSIGNED NOT NULL ,
  `Indoor` DECIMAL(6,1) NULL DEFAULT NULL ,
  `Outdoor` DECIMAL(6,1) NULL DEFAULT NULL ,
  `WindChill` DECIMAL(6,1) NULL DEFAULT NULL ,
  `HeatIndex` DECIMAL(6,1) NULL DEFAULT NULL ,
  `F` CHAR(1) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL ,
  PRIMARY KEY (`RecID`) ,
  INDEX `Temperature_FKIndex1` (`RecID` ASC) ,
  CONSTRAINT `fk_Temperature_DT1`
    FOREIGN KEY (`RecID` )
    REFERENCES `Weather`.`DT` (`RecID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`VersionWeatherDB`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`VersionWeatherDB` (
  `Version` CHAR(10) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL DEFAULT '11.5.0' ,
  `InsertTS` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP ,
  PRIMARY KEY (`Version`) )
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;


-- -----------------------------------------------------
-- Table `Weather`.`Wind`
-- -----------------------------------------------------
CREATE  TABLE IF NOT EXISTS `Weather`.`Wind` (
  `RecID` BIGINT(20) UNSIGNED NOT NULL ,
  `WindSpeed` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `WindDirection` SMALLINT(5) UNSIGNED NULL DEFAULT NULL ,
  `WindRoseDirection` CHAR(3) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NULL DEFAULT NULL ,
  `F` CHAR(1) CHARACTER SET 'utf8' COLLATE 'utf8_unicode_ci' NOT NULL ,
  PRIMARY KEY (`RecID`) ,
  INDEX `Wind_FKIndex1` (`RecID` ASC) ,
  CONSTRAINT `fk_Wind_DT1`
    FOREIGN KEY (`RecID` )
    REFERENCES `Weather`.`DT` (`RecID` )
    ON DELETE NO ACTION
    ON UPDATE NO ACTION)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;



SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
