USE Weather

DELIMITER $$

CREATE PROCEDURE Humidity_HL_UPD(IN nRecID BIGINT, NewOutdoor SMALLINT, NewIndoor SMALLINT)
MODIFIES SQL DATA
BEGIN

DECLARE INSdatetime DATETIME;
DECLARE INSdate DATE;
DECLARE INSymd INTEGER(8);
DECLARE INSym INTEGER(6);
DECLARE INSy SMALLINT(4);
DECLARE INSm SMALLINT(2);
DECLARE INSvpID TINYINT;

DECLARE maxOutHum SMALLINT;
DECLARE minOutHum SMALLINT;

DECLARE maxInHum SMALLINT;
DECLARE minInHum SMALLINT;

SELECT bDateTime, bDate, YearMonthDay, YearMonth, bYear, bMonth, vpID INTO INSdatetime, INSdate, INSymd, INSym, INSy, INSm, INSvpID FROM DT USE INDEX (RecID) WHERE RecID = nRecID;

SELECT OutHumHigh, OutHumLow, InHumHigh, InHumLow INTO maxOutHum, minOutHum, maxInHum, minInHum FROM DHL USE INDEX (PRIMARY) WHERE YearMonthDay = INSymd && vpID = INSvpID;

IF NewOutdoor IS NOT NULL && (NewOutdoor > maxOutHum || maxOutHum IS NULL) THEN
    UPDATE DHL SET OutHumHigh = NewOutdoor, OutHumHighDT = INSdatetime WHERE YearMonthDay = INSymd && vpID = INSvpID;
END IF;

IF NewOutdoor IS NOT NULL && NewOutdoor > 0 && (NewOutdoor < minOutHum || minOutHum IS NULL) THEN
    UPDATE DHL SET OutHumLow = NewOutdoor, OutHumLowDT = INSdatetime WHERE YearMonthDay = INSymd && vpID = INSvpID;
END IF;

IF NewIndoor IS NOT NULL && (NewIndoor > maxInHum || maxInHum IS NULL) THEN
    UPDATE DHL SET InHumHigh = NewIndoor, InHumHighDT = INSdatetime WHERE YearMonthDay = INSymd && vpID = INSvpID;
END IF;

IF NewIndoor IS NOT NULL && NewIndoor > 0 && (NewIndoor < minInHum || minInHum IS NULL) THEN
    UPDATE DHL SET InHumLow = NewIndoor, InHumLowDT = INSdatetime WHERE YearMonthDay = INSymd && vpID = INSvpID;
END IF;

SELECT OutHumHigh, OutHumLow, InHumHigh, InHumLow INTO maxOutHum, minOutHum, maxInHum, minInHum FROM MHL USE INDEX (PRIMARY) WHERE YearMonth = INSym && vpID = INSvpID;

IF NewOutdoor IS NOT NULL && (NewOutdoor > maxOutHum || maxOutHum IS NULL) THEN
    UPDATE MHL SET OutHumHigh = NewOutdoor, OutHumHighDT = INSdatetime WHERE YearMonth = INSym && vpID = INSvpID;
END IF;

IF NewOutdoor IS NOT NULL && NewOutdoor > 0 && (NewOutdoor < minOutHum || minOutHum IS NULL) THEN
    UPDATE MHL SET OutHumLow = NewOutdoor, OutHumLowDT = INSdatetime WHERE YearMonth = INSym && vpID = INSvpID;
END IF;

IF NewIndoor IS NOT NULL && (NewIndoor > maxInHum || maxInHum IS NULL) THEN
    UPDATE MHL SET InHumHigh = NewIndoor, InHumHighDT = INSdatetime WHERE YearMonth = INSym && vpID = INSvpID;
END IF;

IF NewIndoor IS NOT NULL && NewIndoor > 0 && (NewIndoor < minInHum || minInHum IS NULL) THEN
    UPDATE MHL SET InHumLow = NewIndoor, InHumLowDT = INSdatetime WHERE YearMonth = INSym && vpID = INSvpID;
END IF;

SELECT OutHumHigh, OutHumLow, InHumHigh, InHumLow INTO maxOutHum, minOutHum, maxInHum, minInHum FROM YHL USE INDEX (PRIMARY) WHERE bYear = INSy && vpID = INSvpID;

IF NewOutdoor IS NOT NULL && (NewOutdoor > maxOutHum || maxOutHum IS NULL) THEN
    UPDATE YHL SET OutHumHigh = NewOutdoor, OutHumHighDT = INSdatetime WHERE bYear = INSy && vpID = INSvpID;
END IF;

IF NewOutdoor IS NOT NULL && NewOutdoor > 0 && (NewOutdoor < minOutHum || minOutHum IS NULL) THEN
    UPDATE YHL SET OutHumLow = NewOutdoor, OutHumLowDT = INSdatetime WHERE bYear = INSy && vpID = INSvpID;
END IF;

IF NewIndoor IS NOT NULL && (NewIndoor > maxInHum || maxInHum IS NULL) THEN
    UPDATE YHL SET InHumHigh = NewIndoor, InHumHighDT = INSdatetime WHERE bYear = INSy && vpID = INSvpID;
END IF;

IF NewIndoor IS NOT NULL && NewIndoor > 0 && (NewIndoor < minInHum || minInHum IS NULL) THEN
    UPDATE YHL SET InHumLow = NewIndoor, InHumLowDT = INSdatetime WHERE bYear = INSy && vpID = INSvpID;
END IF;

END$$

CREATE PROCEDURE Humidity_HL_SET(IN nRecID BIGINT)
MODIFIES SQL DATA
BEGIN

DECLARE INSdate DATE;
DECLARE INSymd INTEGER(8);
DECLARE INSym INTEGER(6);
DECLARE INSy SMALLINT(4);
DECLARE INSm SMALLINT(2);
DECLARE INSvpID TINYINT;

DECLARE maxOutHum SMALLINT;
DECLARE maxOutHumDT DATETIME;
DECLARE minOutHum SMALLINT;
DECLARE minOutHumDT DATETIME;

DECLARE maxInHum SMALLINT;
DECLARE maxInHumDT DATETIME;
DECLARE minInHum SMALLINT;
DECLARE minInHumDT DATETIME;

SELECT bDate, YearMonthDay, YearMonth, bYear, bMonth, vpID INTO INSdate, INSymd, INSym, INSy, INSm, INSvpID FROM DT USE INDEX (RecID) WHERE RecID = nRecID;

SELECT max(t1.Outdoor), min(t1.Outdoor), max(t1.Indoor), min(t1.Indoor) INTO maxOutHum, minOutHum, maxInHum, minInHum FROM Humidity AS t1 INNER JOIN DT AS t2 USE INDEX (YMDvpID) USING (RecID) WHERE t2.YearMonthDay = INSymd && t2.vpID = INSvpID;

SELECT t2.bDateTime INTO maxOutHumDT FROM Humidity AS t1 INNER JOIN DT as t2 USE INDEX (YMDvpID) USING (RecID) WHERE t1.Outdoor = maxOutHum && t2.YearMonthDay = INSymd && t2.vpID = INSvpID ORDER BY t2.bDateTime LIMIT 1;

SELECT t2.bDateTime INTO minOutHumDT FROM Humidity AS t1 INNER JOIN DT as t2 USE INDEX (YMDvpID) USING (RecID) WHERE t1.Outdoor = minOutHum && t2.YearMonthDay = INSymd && t2.vpID = INSvpID ORDER BY t2.bDateTime LIMIT 1;

SELECT t2.bDateTime INTO maxInHumDT FROM Humidity AS t1 INNER JOIN DT as t2 USE INDEX (YMDvpID) USING (RecID) WHERE t1.Indoor = maxInHum && t2.YearMonthDay = INSymd && t2.vpID = INSvpID ORDER BY t2.bDateTime LIMIT 1;

SELECT t2.bDateTime INTO minInHumDT FROM Humidity AS t1 INNER JOIN DT AS t2 USE INDEX (YMDvpID) USING (RecID) WHERE t1.Indoor = minInHum && t2.YearMonthDay = INSymd && t2.vpID = INSvpID ORDER BY t2.bDateTime LIMIT 1;

UPDATE DHL SET OutHumHigh = maxOutHum, OutHumHighDT = maxOutHumDT, OutHumLow = minOutHum, OutHumLowDT = minOutHumDT, InHumHigh = maxInHum, InHumHighDT = maxInHumDT, InHumLow = minInHum, InHumLowDT = minInHumDT WHERE YearMonthDay = INSymd && vpID = INSvpID;

SELECT max(OutHumHigh), min(OutHumLow), max(InHumHigh), min(InHumLow) INTO maxOutHum, minOutHum, maxInHum, minInHum FROM DHL USE INDEX (PRIMARY) WHERE YearMonth = INSym && vpID = INSvpID;

SELECT OutHumHighDT INTO maxOutHumDT FROM DHL USE INDEX (YMvpID) WHERE OutHumHigh = maxOutHum && YearMonth = INSym && vpID = INSvpID LIMIT 1;

SELECT OutHumLowDT INTO minOutHumDT FROM DHL USE INDEX (YMvpID) WHERE OutHumLow = minOutHum && YearMonth = INSym && vpID = INSvpID LIMIT 1;

SELECT InHumHighDT INTO maxInHumDT FROM DHL USE INDEX (YMvpID) WHERE InHumHigh = maxInHum && YearMonth = INSym && vpID = INSvpID LIMIT 1;

SELECT InHumLowDT INTO minInHumDT FROM DHL USE INDEX (YMvpID) WHERE InHumLow = minInHum && YearMonth = INSym && vpID = INSvpID LIMIT 1;

UPDATE MHL SET OutHumHigh = maxOutHum, OutHumHighDT = maxOutHumDT, OutHumLow = minOutHum, OutHumLowDT = minOutHumDT, InHumHigh = maxInHum, InHumHighDT = maxInHumDT, InHumLow = minInHum, InHumLowDT = minInHumDT WHERE YearMonth = INSym && vpID = INSvpID;

SELECT max(OutHumHigh), min(OutHumLow), max(InHumHigh), min(InHumLow) INTO maxOutHum, minOutHum, maxInHum, minInHum FROM MHL USE INDEX (YvpID) WHERE bYear = INSy && vpID = INSvpID;

SELECT OutHumHighDT INTO maxOutHumDT FROM MHL USE INDEX (YvpID) WHERE OutHumHigh = maxOutHum && bYear = INSy && vpID = INSvpID LIMIT 1;

SELECT OutHumLowDT INTO minOutHumDT FROM MHL USE INDEX (YvpID) WHERE OutHumLow = minOutHum && bYear = INSy && vpID = INSvpID LIMIT 1;

SELECT InHumHighDT INTO maxInHumDT FROM MHL USE INDEX (YvpID) WHERE InHumHigh = maxInHum && bYear = INSy && vpID = INSvpID LIMIT 1;

SELECT InHumLowDT INTO minInHumDT FROM MHL USE INDEX (YvpID) WHERE InHumLow = minInHum && bYear = INSy && vpID = INSvpID LIMIT 1;

UPDATE YHL SET OutHumHigh = maxOutHum, OutHumHighDT = maxOutHumDT, OutHumLow = minOutHum, OutHumLowDT = minOutHumDT, InHumHigh = maxInHum, InHumHighDT = maxInHumDT, InHumLow = minInHum, InHumLowDT = minInHumDT WHERE bYear = INSy && vpID = INSvpID;

END$$

CREATE PROCEDURE Humidity_HL_RCL(IN nYMD INTEGER(8), nvpID TINYINT)
MODIFIES SQL DATA
BEGIN

DECLARE dRecID BIGINT;
DECLARE INSdate DATE;
DECLARE INSymd INTEGER(8);
DECLARE INSym INTEGER(6);
DECLARE INSy SMALLINT(4);
DECLARE INSm SMALLINT(2);
DECLARE INSd SMALLINT(2);
DECLARE dYMD INTEGER(8);

SELECT RecID, bDate, YearMonthDay, YearMonth, bYear, bMonth, bDay INTO dRecID, INSdate, INSymd, INSym, INSy, INSm, INSd FROM DT USE INDEX (YMDvpID) WHERE YearMonthDay = nYMD && vpID = nvpID LIMIT 1;

IF dRecID IS NOT NULL && dRecID > 0 THEN
    SELECT YearMonthDay INTO dYMD FROM YMD USE INDEX (PRIMARY) WHERE YearMonthDay = nYMD && vpID = nvpID LIMIT 1;
    IF dYMD IS NULL THEN
        INSERT IGNORE INTO YMD (YearMonthDay, YearMonth, bDate, bYear, bMonth, bDay, vpID) VALUES (INSymd, INSym, INSdate, INSy, INSm, INSd, nvpID);
    END IF;
    CALL Humidity_HL_SET(dRecID);
END IF;

END$$

CREATE TRIGGER Humidity_INS AFTER INSERT ON Humidity
FOR EACH ROW
BEGIN
CALL Humidity_HL_UPD(NEW.RecID,NEW.Outdoor,NEW.Indoor);
END$$

CREATE TRIGGER Humidity_UPD AFTER UPDATE ON Humidity
FOR EACH ROW
BEGIN
CALL Humidity_HL_UPD(NEW.RecID,NEW.Outdoor,NEW.Indoor);
END$$

CREATE TRIGGER Humidity_DEL AFTER DELETE ON Humidity
FOR EACH ROW
BEGIN
CALL Humidity_HL_SET(OLD.RecID);
END$$


DELIMITER ;


