USE Weather

DELIMITER $$

CREATE PROCEDURE Wind_HL_UPD(IN nRecID BIGINT, NewWindSpeed SMALLINT, NewF CHAR(1))
MODIFIES SQL DATA
BEGIN

DECLARE INSdatetime DATETIME;
DECLARE INSdate DATE;
DECLARE INSymd INTEGER(8);
DECLARE INSym INTEGER(6);
DECLARE INSy SMALLINT(4);
DECLARE INSm SMALLINT(2);
DECLARE INSvpID TINYINT;

DECLARE maxWindSpeed SMALLINT;
DECLARE minWindSpeed SMALLINT;

SELECT bDateTime, bDate, YearMonthDay, YearMonth, bYear, bMonth, vpID INTO INSdatetime, INSdate, INSymd, INSym, INSy, INSm, INSvpID FROM DT USE INDEX (RecID) WHERE RecID = nRecID;

SELECT WindSpeedHigh, WindSpeedLow INTO maxWindSpeed, minWindSpeed FROM DHL USE INDEX (PRIMARY) WHERE YearMonthDay = INSymd && vpID = INSvpID;

IF NewWindSpeed IS NOT NULL && (NewWindSpeed > maxWindSpeed || maxWindSpeed IS NULL) THEN
    UPDATE DHL SET WindSpeedHigh = NewWindSpeed, WindSpeedHighDT = INSdatetime, F = NewF WHERE YearMonthDay = INSymd && vpID = INSvpID;
END IF;

IF NewWindSpeed IS NOT NULL && (NewWindSpeed < minWindSpeed || minWindSpeed IS NULL) THEN
    UPDATE DHL SET WindSpeedLow = NewWindSpeed, WindSpeedLowDT = INSdatetime, F = NewF WHERE YearMonthDay = INSymd && vpID = INSvpID;
END IF;

SELECT WindSpeedHigh, WindSpeedLow INTO maxWindSpeed, minWindSpeed FROM MHL USE INDEX (PRIMARY) WHERE YearMonth = INSym && vpID = INSvpID;

IF NewWindSpeed IS NOT NULL && (NewWindSpeed > maxWindSpeed || maxWindSpeed IS NULL) THEN
    UPDATE MHL SET WindSpeedHigh = NewWindSpeed, WindSpeedHighDT = INSdatetime, F = NewF WHERE YearMonth = INSym && vpID = INSvpID;
END IF;

IF NewWindSpeed IS NOT NULL && (NewWindSpeed < minWindSpeed || minWindSpeed IS NULL) THEN
    UPDATE MHL SET WindSpeedLow = NewWindSpeed, WindSpeedLowDT = INSdatetime, F = NewF WHERE YearMonth = INSym && vpID = INSvpID;
END IF;

SELECT WindSpeedHigh, WindSpeedLow INTO maxWindSpeed, minWindSpeed FROM YHL USE INDEX (PRIMARY) WHERE bYear = INSy && vpID = INSvpID;

IF NewWindSpeed IS NOT NULL && (NewWindSpeed > maxWindSpeed || maxWindSpeed IS NULL) THEN
    UPDATE YHL SET WindSpeedHigh = NewWindSpeed, WindSpeedHighDT = INSdatetime, F = NewF WHERE bYear = INSy && vpID = INSvpID;
END IF;

IF NewWindSpeed IS NOT NULL && (NewWindSpeed < minWindSpeed || minWindSpeed IS NULL) THEN
    UPDATE YHL SET WindSpeedLow = NewWindSpeed, WindSpeedLowDT = INSdatetime, F = NewF WHERE bYear = INSy && vpID = INSvpID;
END IF;

END$$

CREATE PROCEDURE Wind_HL_SET(IN nRecID BIGINT)
MODIFIES SQL DATA
BEGIN

DECLARE INSdate DATE;
DECLARE INSymd INTEGER(8);
DECLARE INSym INTEGER(6);
DECLARE INSy SMALLINT(4);
DECLARE INSm SMALLINT(2);
DECLARE INSvpID TINYINT;

DECLARE maxWindSpeed SMALLINT;
DECLARE maxWindSpeedDT DATETIME;
DECLARE minWindSpeed SMALLINT;
DECLARE minWindSpeedDT DATETIME;

DECLARE curF CHAR(1);

SELECT bDate, YearMonthDay, YearMonth, bYear, bMonth, vpID INTO INSdate, INSymd, INSym, INSy, INSm, INSvpID FROM DT USE INDEX (RecID) WHERE RecID = nRecID;

SELECT F INTO curF FROM Wind USE INDEX (PRIMARY) WHERE RecID = nRecID;

SELECT max(t1.WindSpeed), min(t1.WindSpeed) INTO maxWindSpeed, minWindSpeed FROM Wind AS t1 INNER JOIN DT AS t2 USE INDEX (YMDvpID) USING (RecID) WHERE t2.YearMonthDay = INSymd && t2.vpID = INSvpID;

SELECT t2.bDateTime INTO maxWindSpeedDT FROM Wind AS t1 INNER JOIN DT AS t2 USE INDEX (YMDvpID) USING (RecID) WHERE t1.WindSpeed = maxWindSpeed && t2.YearMonthDay = INSymd && t2.vpID = INSvpID ORDER BY t2.bDateTime LIMIT 1;

SELECT t2.bDateTime INTO minWindSpeedDT FROM Wind AS t1 INNER JOIN DT AS t2 USE INDEX (YMDvpID) USING (RecID) WHERE t1.WindSpeed = minWindSpeed && t2.YearMonthDay = INSymd && t2.vpID = INSvpID ORDER BY t2.bDateTime LIMIT 1;

UPDATE DHL SET WindSpeedHigh = maxWindSpeed, WindSpeedHighDT = maxWindSpeedDT, WindSpeedLow = minWindSpeed, WindSpeedLowDT = minWindSpeedDT, F = curF WHERE YearMonthDay = INSymd && vpID = INSvpID;

SELECT max(WindSpeedHigh), min(WindSpeedLow) INTO maxWindSpeed, minWindSpeed FROM DHL USE INDEX (YMvpID) WHERE YearMonth = INSym && vpID = INSvpID;

SELECT WindSpeedHighDT INTO maxWindSpeedDT FROM DHL USE INDEX (YMvpID) WHERE WindSpeedHigh = maxWindSpeed && YearMonth = INSym && vpID = INSvpID LIMIT 1;

SELECT WindSpeedLowDT INTO minWindSpeedDT FROM DHL USE INDEX (YMvpID) WHERE WindSpeedLow = minWindSpeed && YearMonth = INSym && vpID = INSvpID LIMIT 1;

UPDATE MHL SET WindSpeedHigh = maxWindSpeed, WindSpeedHighDT = maxWindSpeedDT, WindSpeedLow = minWindSpeed, WindSpeedLowDT = minWindSpeedDT, F = curF WHERE YearMonth = INSym && vpID = INSvpID;

SELECT max(WindSpeedHigh), min(WindSpeedLow) INTO maxWindSpeed, minWindSpeed FROM MHL USE INDEX (YvpID) WHERE bYear = INSy && vpID = INSvpID;

SELECT WindSpeedHighDT INTO maxWindSpeedDT FROM MHL USE INDEX (YvpID) WHERE WindSpeedHigh = maxWindSpeed && bYear = INSy && vpID = INSvpID LIMIT 1;

SELECT WindSpeedLowDT INTO minWindSpeedDT FROM MHL USE INDEX (YvpID) WHERE WindSpeedLow = minWindSpeed && bYear = INSy && vpID = INSvpID LIMIT 1;

UPDATE YHL SET WindSpeedHigh = maxWindSpeed, WindSpeedHighDT = maxWindSpeedDT, WindSpeedLow = minWindSpeed, WindSpeedLowDT = minWindSpeedDT, F = curF WHERE bYear = INSy && vpID = INSvpID;

END$$

CREATE PROCEDURE Wind_HL_RCL(IN nYMD INTEGER(8), nvpID TINYINT)
MODIFIES SQL DATA
BEGIN

DECLARE dRecID BIGINT;
DECLARE INSdate DATE;
DECLARE INSymd INTEGER(8);
DECLARE INSym INTEGER(6);
DECLARE INSy SMALLINT(4);
DECLARE INSm SMALLINT(2);
DECLARE INSd SMALLINT(2);
DECLARE dYMD INTEGER(8);

SELECT RecID, bDate, YearMonthDay, YearMonth, bYear, bMonth, bDay INTO dRecID, INSdate, INSymd, INSym, INSy, INSm, INSd FROM DT USE INDEX (YMDvpID) WHERE YearMonthDay = nYMD && vpID = nvpID LIMIT 1;

IF dRecID IS NOT NULL && dRecID > 0 THEN
    SELECT YearMonthDay INTO dYMD FROM YMD USE INDEX (PRIMARY) WHERE YearMonthDay = nYMD && vpID = nvpID LIMIT 1;
    IF dYMD IS NULL THEN
        INSERT IGNORE INTO YMD (YearMonthDay, YearMonth, bDate, bYear, bMonth, bDay, vpID) VALUES (INSymd, INSym, INSdate, INSy, INSm, INSd, nvpID);
    END IF;
    CALL Wind_HL_SET(dRecID);
END IF;

END$$

CREATE TRIGGER Wind_INS AFTER INSERT ON Wind
FOR EACH ROW
BEGIN
CALL Wind_HL_UPD(NEW.RecID,NEW.WindSpeed,NEW.F);
END$$

CREATE TRIGGER Wind_UPD AFTER UPDATE ON Wind
FOR EACH ROW
BEGIN
CALL Wind_HL_UPD(NEW.RecID,NEW.WindSpeed,NEW.F);
END$$

CREATE TRIGGER Wind_DEL AFTER DELETE ON Wind
FOR EACH ROW
BEGIN
CALL Wind_HL_SET(OLD.RecID);
END$$


DELIMITER ;


