USE Weather

INSERT INTO VersionWeatherDB (Version) VALUES ("11.5.0s");

SELECT 'Creating Location Table';
CREATE TABLE IF NOT EXISTS Location (
  vpID TINYINT UNSIGNED NOT NULL,
  Model TEXT NULL,
  SN TEXT NULL,
  Description TEXT NULL,
  Address TEXT NULL,
  City TEXT NULL,
  County TEXT NULL,
  State TEXT NULL,
  Country TEXT NULL,
  Longitude DECIMAL(12,6) NULL,
  Latitude DECIMAL(12,6) NULL,
  Contact TEXT NULL,
  InsertTS TIMESTAMP NOT NULL,
  PRIMARY KEY (vpID)
)
ENGINE = MyISAM
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_unicode_ci;

DESC Location;

SELECT 'Updating IndexDT Table';
DESC IndexDT;

ALTER TABLE IndexDT ADD COLUMN vpID TINYINT UNSIGNED NOT NULL DEFAULT 0 AFTER RecID;
ALTER TABLE IndexDT DROP PRIMARY KEY, ADD CONSTRAINT PRIMARY KEY (vpID,RecID);
ALTER TABLE IndexDT ADD COLUMN vpIDorgRecID BIGINT UNSIGNED NULL AFTER wxTT;
ALTER TABLE IndexDT ADD COLUMN bTT BIGINT(20) UNSIGNED NULL DEFAULT NULL AFTER wxTT;
ALTER TABLE IndexDT ADD COLUMN sTT BIGINT(20) UNSIGNED NULL DEFAULT NULL AFTER bTT;
ALTER TABLE IndexDT ADD COLUMN eTT BIGINT(20) UNSIGNED NULL DEFAULT NULL AFTER sTT;
ALTER TABLE IndexDT ADD COLUMN rt INT UNSIGNED NULL DEFAULT NULL AFTER eTT;
ALTER TABLE IndexDT DROP INDEX rttt, ADD INDEX rtTT (rtTT);
ALTER TABLE IndexDT DROP INDEX wxtt, ADD INDEX wxTT (wxTT);
ALTER TABLE IndexDT ADD INDEX bTT (bTT);
ALTER TABLE IndexDT ADD INDEX sTT (sTT);
ALTER TABLE IndexDT ADD INDEX vpIDorgRecID (vpID,vpIDorgRecID);
ALTER IGNORE TABLE IndexDT ADD CONSTRAINT fk_IndexDT_Location1 FOREIGN KEY (vpID) REFERENCES Location (vpID) ON DELETE NO ACTION ON UPDATE NO ACTION;
UPDATE IndexDT AS t1 INNER JOIN DT AS t2 USING (RecID) SET t1.bTT = t2.bTT WHERE t1.RecID = t2.RecID && ((t1.bTT IS NULL && t2.bTT IS NOT NULL) || t1.bTT != t2.bTT);

SHOW KEYS FROM IndexDT;

DESC IndexDT;

SELECT 'Updating DT Table';
DESC DT;

ALTER TABLE DT ADD COLUMN vpID TINYINT UNSIGNED NOT NULL DEFAULT 0 AFTER RecID;
ALTER TABLE DT DROP PRIMARY KEY, ADD CONSTRAINT PRIMARY KEY (bDateTime,DST,vpID);
ALTER TABLE DT ADD COLUMN vpIDorgRecID BIGINT UNSIGNED NULL AFTER bTT;
ALTER TABLE DT ADD INDEX bDateTime (bDateTime);
ALTER TABLE DT ADD INDEX vpIDorgRecID (vpID,vpIDorgRecID);
ALTER TABLE DT ADD INDEX YMDvpID (vpID,YearMonthDay);
ALTER IGNORE TABLE DT ADD CONSTRAINT fk_DT_IndexDT1 FOREIGN KEY (RecID) REFERENCES IndexDT (RecID) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER IGNORE TABLE DT ADD CONSTRAINT fk_DT_IndexDT2 FOREIGN KEY (bTT) REFERENCES IndexDT (bTT) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER IGNORE TABLE DT ADD CONSTRAINT fk_DT_Location1 FOREIGN KEY (vpID) REFERENCES Location (vpID) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER IGNORE TABLE DT ADD CONSTRAINT fk_DT_YMD1 FOREIGN KEY (YearMonthDay) REFERENCES YMD (YearMonthDay) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM DT;

DESC DT;

SELECT 'Updating Storms Table';
DESC Storms;

ALTER TABLE Storms ADD COLUMN vpID TINYINT UNSIGNED NOT NULL DEFAULT 0 FIRST;
ALTER TABLE Storms MODIFY COLUMN StormAmount DECIMAL(7,2) NULL DEFAULT NULL;
ALTER TABLE Storms MODIFY COLUMN HighestRate DECIMAL(7,2) NULL DEFAULT NULL;
ALTER TABLE Storms MODIFY COLUMN F CHAR(1) NOT NULL;
ALTER TABLE Storms DROP PRIMARY KEY, ADD CONSTRAINT PRIMARY KEY (StormStartedDate,vpID);
ALTER IGNORE TABLE Storms ADD CONSTRAINT fk_Storms_Location1 FOREIGN KEY (vpID) REFERENCES Location (vpID) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER IGNORE TABLE Storms ADD CONSTRAINT fk_Storms_Rain1 FOREIGN KEY (StormStartedDate) REFERENCES Rain (StormStartedDate) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM Storms;

DESC Storms;

SELECT 'Updating YMD Table';
DESC YMD;

ALTER TABLE YMD ADD COLUMN vpID TINYINT UNSIGNED NOT NULL DEFAULT 0 FIRST;
ALTER TABLE YMD DROP PRIMARY KEY, ADD CONSTRAINT PRIMARY KEY (YearMonthDay,vpID);
ALTER IGNORE TABLE YMD ADD CONSTRAINT fk_YMD_Location1 FOREIGN KEY (vpID) REFERENCES Location (vpID) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM YMD;

DESC YMD;

SELECT 'Updating DHL Table';
DESC DHL;

ALTER TABLE DHL ADD COLUMN vpID TINYINT UNSIGNED NOT NULL DEFAULT 0 FIRST;
ALTER TABLE DHL DROP PRIMARY KEY, ADD CONSTRAINT PRIMARY KEY (YearMonthDay,vpID);
ALTER TABLE DHL ADD COLUMN F CHAR(1) NOT NULL AFTER HourlyETHighDT;
ALTER TABLE DHL MODIFY COLUMN RainDayTotal DECIMAL(7,2) NULL DEFAULT NULL;
ALTER TABLE DHL MODIFY COLUMN HourlyRainAmount DECIMAL(7,2) NULL DEFAULT NULL;
ALTER TABLE DHL MODIFY COLUMN HourlyRainRate DECIMAL(7,2) NULL DEFAULT NULL;
ALTER TABLE DHL ADD INDEX YMvpID (YearMonth,vpID);
ALTER IGNORE TABLE DHL ADD CONSTRAINT fk_DHL_Location1 FOREIGN KEY (vpID) REFERENCES Location (vpID) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER IGNORE TABLE DHL ADD CONSTRAINT fk_DHL_MHL2 FOREIGN KEY (YearMonth) REFERENCES MHL (YearMonth) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER IGNORE TABLE DHL ADD CONSTRAINT fk_DHL_YMD1 FOREIGN KEY (YearMonthDay) REFERENCES YMD (YearMonthDay) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM DHL;

DESC DHL;

SELECT 'Updating MHL Table';
DESC MHL;

ALTER TABLE MHL ADD COLUMN vpID TINYINT UNSIGNED NOT NULL DEFAULT 0 FIRST;
ALTER TABLE MHL DROP PRIMARY KEY, ADD CONSTRAINT PRIMARY KEY (YearMonth,vpID);
ALTER TABLE MHL ADD COLUMN F CHAR(1) NOT NULL AFTER HourlyETHighDT;
ALTER TABLE MHL MODIFY COLUMN RainDayTotal DECIMAL(7,2) NULL DEFAULT NULL;
ALTER TABLE MHL ADD INDEX YvpID (bYear,vpID);
ALTER IGNORE TABLE MHL ADD CONSTRAINT fk_MHL_Location1 FOREIGN KEY (vpID) REFERENCES Location (vpID) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER IGNOREM TABLE MHL ADD CONSTRAINT fk_MHL_YHL1 FOREIGN KEY (bYear) REFERENCES YHL (bYear) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM MHL;

DESC MHL;

SELECT 'Updating YHL Table';
DESC YHL;

ALTER TABLE YHL ADD COLUMN vpID TINYINT UNSIGNED NOT NULL DEFAULT 0 FIRST;
ALTER TABLE YHL DROP PRIMARY KEY, ADD CONSTRAINT PRIMARY KEY (bYear,vpID);
ALTER TABLE YHL ADD COLUMN F CHAR(1) NOT NULL AFTER HourlyETHighDT;
ALTER TABLE YHL MODIFY COLUMN RainDayTotal DECIMAL(7,2) NULL DEFAULT NULL;
ALTER IGNORE TABLE YHL ADD CONSTRAINT fk_YHL_Location1 FOREIGN KEY (vpID) REFERENCES Location (vpID) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM YHL;

DESC YHL;

SELECT 'Updating Rain Table';
DESC Rain;

ALTER TABLE Rain ADD COLUMN PerMinute DECIMAL(8,3) NULL DEFAULT NULL AFTER IncrementalRain;
ALTER TABLE Rain MODIFY COLUMN DayAmount DECIMAL(7,2) NULL DEFAULT NULL;
ALTER TABLE Rain MODIFY COLUMN StormAmount DECIMAL(7,2) NULL DEFAULT NULL;
ALTER TABLE Rain MODIFY COLUMN F CHAR(1) NOT NULL;
ALTER IGNORE TABLE Rain ADD CONSTRAINT fk_Rain_DT1 FOREIGN KEY (RecID) REFERENCES DT (RecID) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM Rain;

SELECT 'Updating Wind Table';
DESC Rain;

DESC Wind;

ALTER TABLE Wind MODIFY COLUMN F CHAR(1) NOT NULL;
ALTER IGNORE TABLE Wind ADD CONSTRAINT fk_Wind_DT1 FOREIGN KEY (RecID) REFERENCES DT (RecID) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM Wind;

DESC Wind;

SELECT 'Updating Temperature Table';
DESC Temperature;

ALTER TABLE Temperature MODIFY COLUMN F CHAR(1) NOT NULL;
ALTER IGNORE TABLE Temperature ADD CONSTRAINT fk_Temperature_DT1 FOREIGN KEY (RecID) REFERENCES DT (RecID) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM Temperature;

DESC Temperature;

SELECT 'Updating Baromter Table';
DESC Barometer;

ALTER TABLE Barometer MODIFY COLUMN F CHAR(1) NOT NULL;
ALTER IGNORE TABLE Barometer ADD CONSTRAINT fk_Barometer_DT1 FOREIGN KEY (RecID) REFERENCES DT (RecID) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM Barometer;

DESC Barometer;

SELECT 'Updating Humidity Table';
DESC Humidity;

ALTER IGNORE TABLE Humidity ADD CONSTRAINT fk_Humidity_DT1 FOREIGN KEY (RecID) REFERENCES DT (RecID) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM Humidity;

DESC Humidity;

SELECT 'Updating Solar Table';
DESC Solar;

ALTER TABLE Solar MODIFY COLUMN MinutesRad DECIMAL(6,2) NULL DEFAULT NULL;
ALTER TABLE Solar MODIFY COLUMN MinutesUV DECIMAL(6,2) NULL DEFAULT NULL;
ALTER IGNORE TABLE Solar ADD CONSTRAINT fk_Solar_DT1 FOREIGN KEY (RecID) REFERENCES DT (RecID) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM Solar;

DESC Solar;

SELECT 'Updating Hourly Table';
DESC Hourly;

ALTER TABLE Hourly MODIFY COLUMN F CHAR(1) NOT NULL;
ALTER IGNORE TABLE Hourly ADD CONSTRAINT fk_Hourly_DT1 FOREIGN KEY (RecID) REFERENCES DT (RecID) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER IGNORE TABLE Hourly ADD CONSTRAINT fk_Hourly_Forecasts1 FOREIGN KEY (ForecastRuleNumber) REFERENCES Forecasts (ForecastRuleNumber) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM Hourly;

DESC Hourly;

SELECT 'Updating Avg10Min Table';
DESC Avg10Min;

ALTER TABLE Hourly MODIFY COLUMN RainAmount DECIMAL(7,2) NULL DEFAULT NULL;
ALTER IGNORE TABLE Avg10Min ADD CONSTRAINT fk_Avg10Min_DT1 FOREIGN KEY (RecID) REFERENCES DT (RecID) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM Avg10Min;

DESC Avg10Min;

SELECT 'Updating Avg15Min Table';
DESC Avg15Min;

ALTER IGNORE TABLE Avg15Min ADD CONSTRAINT fk_Avg15Min_DT1 FOREIGN KEY (RecID) REFERENCES DT (RecID) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM Avg15Min;

DESC Avg15Min;

SELECT 'Updating MinPtrData Table';
DESC MinPtrData;

ALTER TABLE MinPtrData ADD COLUMN vpID TINYINT UNSIGNED NOT NULL DEFAULT 0 FIRST;
ALTER TABLE MinPtrData MODIFY COLUMN RecID BIGINT(20) UNSIGNED NULL DEFAULT NULL AFTER vpID;
ALTER IGNORE TABLE MinPtrData ADD CONSTRAINT fk_MinPtrData_DT1 FOREIGN KEY (bDateTime) REFERENCES DT (bDateTime) ON DELETE NO ACTION ON UPDATE NO ACTION;
ALTER IGNORE TABLE MinPtrData ADD CONSTRAINT fk_MinPtrData_Location1 FOREIGN KEY (vpID) REFERENCES Location (vpID) ON DELETE NO ACTION ON UPDATE NO ACTION;

SHOW KEYS FROM MinPtrData;

DESC MinPtrData;

SELECT 'Rebuilding Indexes Avg10Min';
ALTER TABLE Avg10Min ENGINE = MyISAM;

SELECT 'Rebuilding Indexes Avg15Min';
ALTER TABLE Avg15Min ENGINE = MyISAM;

SELECT 'Rebuilding Indexes Barometer';
ALTER TABLE Barometer ENGINE = MyISAM;

SELECT 'Rebuilding Indexes DHL';
ALTER TABLE DHL ENGINE = MyISAM;

SELECT 'Rebuilding Indexes DT';
ALTER TABLE DT ENGINE = MyISAM;

SELECT 'Rebuilding Indexes Forecasts';
ALTER TABLE Forecasts ENGINE = MyISAM;

SELECT 'Rebuilding Indexes Hourly';
ALTER TABLE Hourly ENGINE = MyISAM;

SELECT 'Rebuilding Indexes ';
ALTER TABLE Humidity ENGINE = MyISAM;

SELECT 'Rebuilding Indexes IndexDT';
ALTER TABLE IndexDT ENGINE = MyISAM;

SELECT 'Rebuilding Indexes Location';
ALTER TABLE Location ENGINE = MyISAM;

SELECT 'Rebuilding Indexes MHL';
ALTER TABLE MHL ENGINE = MyISAM;

SELECT 'Rebuilding Indexes MinPtrData';
ALTER TABLE MinPtrData ENGINE = MyISAM;

SELECT 'Rebuilding Indexes Rain';
ALTER TABLE Rain ENGINE = MyISAM;

SELECT 'Rebuilding Indexes Solar';
ALTER TABLE Solar ENGINE = MyISAM;

SELECT 'Rebuilding Indexes Storms';
ALTER TABLE Storms ENGINE = MyISAM;

SELECT 'Rebuilding Indexes Temperature';
ALTER TABLE Temperature ENGINE = MyISAM;

SELECT 'Rebuilding Indexes VersionWeatherDB';
ALTER TABLE VersionWeatherDB ENGINE = MyISAM;

SELECT 'Rebuilding Indexes Wind';
ALTER TABLE Wind ENGINE = MyISAM;

SELECT 'Rebuilding Indexes YHL';
ALTER TABLE YHL ENGINE = MyISAM;

SELECT 'Rebuilding Indexes YMD';
ALTER TABLE YMD ENGINE = MyISAM;


SOURCE WeatherDB-11.5_TriggersAdd.sql;

UPDATE VersionWeatherDB SET Version = "11.5.0" WHERE Version = "11.5.0s";

