/********************************************************************************/
/*  vproweather 1.0.9  								*/
/*	A program for acquiring data from a Davis Vantage Pro Weather Station.	*/
/*										*/
/* (c)2005-2013 Curt Blank email: curt@curtronics.com				*/
/* VPROWEATHER is covered under the GNU general license. See the attached	*/
/* LICENSE file for details.							*/
/*										*/
/* This software is provided as-is, without any expressed or implied		*/
/* warranties, including, without limitation, the implied warranties of		*/
/* merchantibility and fitness for any particular purpose.			*/
/*										*/
/*										*/
/* mySQLnames.h - definition of DB columns					*/
/*                                                                              */
/* WARNING!! If you're inclined to change column names you must also make the   */
/*           changes in the DB creation scripts as applicable. No assistance    */
/*           for that will be provided.                                         */
/*      									*/
/*     v0.8-0 cjb - new								*/
/*     v1.0.0 cjb - add _CURRENT_RAIN_COL in Rain table                         */
/*                - changed _CURRENT_RAIN_COL to INCREMENTAL_RAIN_COL - there   */
/*                  is no way to insure it is the current rain, only that it is */
/*                  the incremental amount since the last reading               */
/*                - changed definition of _STORM_START_DATE_COL                 */
/*                - changed definition of _RAIN_STORMS_START_DATE_COL           */
/*                - changed definition of _RAIN_STORMS_END_DATE_COL             */
/*                - added definition _RAIN_STORMS_START_TIME_COL                */
/*                - added definition _RAIN_STORMS_END_TIME_COL                  */
/*                - added definition _SOLAR_NOON_COL                            */
/*     v1.0.8 cjb - added definition _PER_MINUTE_RAIN_COL                       */
/*										*/
/********************************************************************************/

#ifndef __MYSQLNAMES_H__
#define __MYSQLHAMES_H__

#ifdef __cplusplus
#define extern "C" {		/* respect c++ callers */
#endif

/* mySQL Tables */

/* Location Table name and contents */
#define _LOCATION_TABLE_NAME            "Location"
#define _LOCATION_MODEL_COL             "Model"
#define _LOCATION_SN_COL                "SN"
#define _LOCATION_DESC_COL              "Description"
#define _LOCATION_ADDRESS_COL           "Address"
#define _LOCATION_CITY_COL              "City"
#define _LOCATION_COUNTY_COL            "County"
#define _LOCATION_STATE_COL             "State"
#define _LOCATION_COUNTRY_COL           "Country"
#define _LOCATION_LONG_COL              "Longitude"
#define _LOCATION_LAT_COL               "Latitude"
#define _LOCATION_CONTACT_COL           "Contact"

/* Barometer Table name and contents */
#define _BARO_TABLE_NAME		"Barometer"
#define _BARO_TREND_COL                 "Trend"
#define _BARO_TREND_IMG_COL             "TrendImage"
#define _BARO_CURR_COL                  "Pressure"

/* Temperature Table name and contents */
#define _TEMP_TABLE_NAME		"Temperature"
#define _INSIDE_TEMP_COL                "Indoor"
#define _OUTSIDE_TEMP_COL               "Outdoor"
#define _HEATINDEX_COL                  "HeatIndex"
#define _WINDCHILL_COL                  "WindChill"

/* Rain Table name and contents */
#define _RAIN_TABLE_NAME		"Rain"
#define _IS_RAINING_COL                 "CurrentlyRaining"
#define _INCREMENTAL_RAIN_COL		"IncrementalRain"
#define _PER_MINUTE_RAIN_COL		"PerMinute"
#define _RAIN_RATE_COL                  "Rate"
#define _RAIN_STORM_COL                 "StormAmount"
#define _RAIN_STORM_COL_INDEX		"StormAmount"
#define _STORM_START_DATE_COL           "StormStartedDate"
#define _DAY_RAIN_COL                   "DayAmount"
#define _DAY_ET_COL			"ET"

/* Rainstorms Table name and contents */
#define _STORMS_TABLE_NAME		"Storms"
#define _RAIN_STORMS_START_DATE_COL     "StormStartedDate"
#define _RAIN_STORMS_START_TIME_COL	"StormStartedTime"
#define _RAIN_STORMS_END_DATE_COL       "StormEndedDate"
#define _RAIN_STORMS_END_TIME_COL	"StormEndedTime"
#define _RAIN_STORMS_AMOUNT_COL		"StormAmount"
#define _RAIN_STORMS_HIGH_RATE_COL	"HighestRate"
#define _RAIN_STORMS_HIGH_RATE_DT_COL	"HighestRateDT"

/* Humidity Table name and contents */
#define _HUM_TABLE_NAME			"Humidity"
#define _INSIDE_HUM_COL                 "Indoor"
#define _OUTSIDE_HUM_COL                "Outdoor"

/* Wind Table name and contents */
#define _WIND_TABLE_NAME		"Wind"
#define _WIND_SPEED_COL                 "WindSpeed"
#define _WIND_DIR_COL                   "WindDirection"
#define _WIND_DIR_ROSE_COL              "WindRoseDirection"

/* Solar Table name and contents */
#define _SOLAR_TABLE_NAME		"Solar"
#define _SOLAR_RAD_COL                  "Radiation"
#define _SOLAR_RAD_MIN_COL		"MinutesRad"
#define _UV_COL				"UV"
#define _UV_MIN_COL			"MinutesUV"

/* 10 minute averaged data Table name and contents */
#define _10MIN_TABLE_NAME		"Avg10Min"
#define _10MIN_CUR_PTR_COL		"Cur10MinPtr"
#define _10MIN_LAST_PTR_COL		"Last10MinPtr"
#define _10MIN_WIND_AVG_BY_RPT_COL	"WindSpeedRpt"
#define _10MIN_WIND_AVG_BY_CALC_COL	"WindSpeedCalc"

/* 15 minute averaged data Table name and contents */
#define _15MIN_TABLE_NAME		"Avg15Min"
#define _15MIN_CUR_PTR_COL		"Cur15MinPtr"
#define _15MIN_LAST_PTR_COL		"Last15MinPtr"
#define _15MIN_BAR_BY_RPT_COL		"BaroPressureRpt"
#define _15MIN_BAR_BY_CALC_COL		"BaroPressureCalc"
#define _15MIN_RAIN_BY_RPT_COL		"RainAmountRpt"
#define _15MIN_RAIN_BY_CALC_COL		"RainAmountCalc"

/* Table used to determine 10 & 15 Minute Pointer values       */
/* NOTE: See Doc & Code -- Davis does not update the pointer   */
/* values except at, and only at, startup (i.e. Console boot)  */
/* NOTE: You should never need to access or alter data in this */
/* table it is only used internally to determine pointer value */
/* and current values for 10 & 15 minute data - altering data  */
/* in table may/will invalidate data in the _10MIN_TABLE_NAME  */
/* & _15MIN_TABLE_NAME either temporarily or permanently       */
#define _MINUTE_PTR_DATA_TABLE_NAME	"MinPtrData"
#define _MIN_PTR_POINTER_COL		"Ptr"
#define _MIN_PTR_ITEM_NAME_COL		"Item"
#define _MIN_PTR_ITEM_DATA_COL		"ItemData"
#define _MIN_PTR_REF10MIN		"grTimeRef10Min"
#define _MIN_PTR_REF15MIN		"grTimeRef15Min"
#define _MIN_PTR_BARO15MIN		"grBarBy15Min"
#define _MIN_PTR_WIND10MIN		"grWindAvgBy10Min"
#define _MIN_PTR_RAIN15MIN		"grRainBy15Min"

/* Forcast Table name and contents */
#define _FORECAST_TABLE_NAME		"Hourly"
#define _FORE_ICON_COL                  "ForecastIconNumber"
#define _FORE_RULE_COL                  "ForecastRuleNumber"

/* Sunrise/Sunset Table name and contents */
#define _SUN_TABLE_NAME			"YMD"
#define _SUNRISE_COL                    "Sunrise"
#define _SUNSET_COL                     "Sunset"
#define _SOLAR_NOON_COL			"SolarNoon"

/* Hourly Data Table name and contents */
#define _HOURLY_TABLE_NAME              "Hourly"
#define _IN_TEMP_BY_HOURS_COL           "InTemp"
#define _TEMP_BY_HOURS_COL              "OutTemp"
#define _CHILL_LO_BY_HOURS_COL          "WindChill"
#define _HEAT_HI_BY_HOURS_COL           "HeatIndex"
#define _IN_HUM_BY_HOURS_COL            "InHum"
#define _HUM_BY_HOURS_COL               "OutHum"
#define _WIND_AVG_BY_HOURS_COL          "WindSpeedAvg"
#define _WIND_DIR_BY_HOURS_COL          "WindDirAvg"
#define _WIND_HI_BY_HOURS_COL           "WindSpeedHigh"
#define _DEW_BY_HOURS_COL               "DewPoint"
#define _THSW_HI_BY_HOURS_COL           "THSWIndex"
#define _SOLAR_BY_HOUR_AVG_COL          "SolarRadAvg"
#define _BAR_BY_HOURS_COL               "Barometer"
#define _ET_BY_HOUR_COL                 "ET"
#define _RAIN_BY_HOUR_COL               "RainAmount"
#define _RAIN_RATE_BY_HOURS_COL         "RainRate"
#define _FORECAST_RULE_NUM_COL          "ForecastRuleNumber"
#define _FORECAST_ICON_NUM_COL          "ForecastIconNumber"

/* DHL Table name and contents */
#define _DHL_TABLE_NAME                 "DHL"
#define _THSW_DHL_TABLE_NAME            "DHL"
#define _THSW_DHL_HI_COL                "THSWHigh"
#define _THSW_DHL_HI_TIME_COL           "THSWHighDT"
#define _UV_DHL_TABLE_NAME              "DHL"
#define _UV_DHL_HI_COL                  "UVHigh"
#define _UV_DHL_HI_TIME_COL             "UVHighDT"
#define _DEW_DHL_TABLE_NAME             "DHL"
#define _DEW_DHL_HI_COL                 "DewPointHigh"
#define _DEW_DHL_HI_TIME_COL            "DewPointHighDT"
#define _DEW_DHL_LO_COL                 "DewPointLow"
#define _DEW_DHL_LO_TIME_COL            "DewPointLowDT"

/* */
#define _WIND_AVG_SPEED_COL		""
#define _SOIL_TEMP_COL			""
#define _LEAF_TEMP_COL			""
#define _UV_INDEX_COL			""
#define _MONTH_RAIN_COL			""
#define _YEAR_RAIN_COL			""
#define _MONTH_ET_COL			""
#define _YEAR_ET_COL			""
#define _XMIT_BATT_COL			""
#define _BATT_VOLTAGE_COL		""
#define _FORE_STRING_COL		""


/* highs/lows data */
#define _BARO_LO_DAY_COL		""
#define _BARO_HI_DAY_COL		""
#define _BARO_LO_MONTH_COL		""
#define _BARO_HI_MONTH_COL		""
#define _BARO_LO_YEAR_COL		""
#define _BARO_HI_YEAR_COL		""
#define _BARO_LO_TIME_COL		""
#define _BARO_HI_TIME_COL		""
#define _WIND_HI_DAY_COL		""
#define _WIND_HI_TIME_COL		""
#define _WIND_HI_MONTH_COL		""
#define _WIND_HI_YEAR_COL		""
#define _IN_TEMP_BY_DAY_COL		""
#define _IN_TEMP_HI_DAY_COL		""
#define _IN_TEMP_LO_DAY_COL		""
#define _IN_TEMP_HI_TIME_COL		""
#define _IN_TEMP_LO_TIME_COL		""
#define _IN_TEMP_LO_MONTH_COL		""
#define _IN_TEMP_HI_MONTH_COL		""
#define _IN_TEMP_LO_YEAR_COL		""
#define _IN_TEMP_HI_YEAR_COL		""
#define _IN_HUM_HI_DAY_COL		""
#define _IN_HUM_LO_DAY_COL		""
#define _IN_HUM_HI_TIME_COL		""
#define _IN_HUM_LO_TIME_COL		""
#define _IN_HUM_HI_MONTH_COL		""
#define _IN_HUM_LO_MONTH_COL		""
#define _IN_HUM_HI_YEAR_COL		""
#define _IN_HUM_LO_YEAR_COL		""
#define _TEMP_HI_DAY_COL		""
#define _TEMP_LO_DAY_COL		""
#define _TEMP_HI_TIME_COL		""
#define _TEMP_LO_TIME_COL		""
#define _TEMP_LO_MONTH_COL		""
#define _TEMP_HI_MONTH_COL		""
#define _TEMP_LO_YEAR_COL		""
#define _TEMP_HI_YEAR_COL		""
#define _DEW_LO_DAY_COL			""
#define _DEW_HI_DAY_COL			""
#define _DEW_LO_TIME_COL		""
#define _DEW_HI_TIME_COL		""
#define _DEW_HI_MONTH_COL		""
#define _DEW_LO_MONTH_COL		""
#define _DEW_HI_YEAR_COL		""
#define _DEW_LO_YEAR_COL		""
#define _CHILL_LO_DAY_COL		""
#define _CHILL_LO_TIME_COL		""
#define _CHILL_LO_MONTH_COL		""
#define _CHILL_LO_YEAR_COL		""
#define _HEAT_HI_DAY_COL		""
#define _HEAT_HI_TIME_COL		""
#define _HEAT_HI_MONTH_COL		""
#define _HEAT_HI_YEAR_COL		""
#define _THSW_HI_DAY_COL		""
#define _THSW_HI_TIME_COL		""
#define _THSW_HI_MONTH_COL		""
#define _THSW_HI_YEAR_COL		""
#define _SOLAR_HI_DAY_COL		""
#define _SOLAR_HI_TIME_COL		""
#define _SOLAR_HI_MONTH_COL		""
#define _SOLAR_HI_YEAR_COL		""
#define _UV_HI_DAY_COL			""
#define _UV_HI_TIME_COL			""
#define _UV_HI_MONTH_COL		""
#define _UV_HI_YEAR_COL			""
#define _UV_HI_DAY_COL			""
#define _UV_HI_TIME_COL			""
#define _UV_HI_MONTH_COL		""
#define _UV_HI_YEAR_COL			""
#define _RAIN_RATE_HI_DAY_COL		""
#define _RAIN_RATE_HI_TIME_COL		""
#define _RAIN_RATE_HI_HOUR_COL		""
#define _RAIN_RATE_HI_MONTH_COL		""
#define _RAIN_RATE_HI_YEAR_COL		""


/* graph data */
#define _TIME_REF_10MIN_COL		""
#define _TIME_REF_15MIN_COL		""
#define _TIME_REF_HOURS_COL		""
#define _TIME_REF_DAYS_COL		""
#define _TIME_REF_MONTHS_COL		""
#define _TIME_REF_YEARS_COL		""
#define _IN_TEMP_HI_BY_DAYS_COL		""
#define _IN_TEMP_HI_BY_DAYS_TIME_COL	""
#define _IN_TEMP_LO_BY_DAYS_COL		""
#define _IN_TEMP_LO_BY_DAYS_TIME_COL	""
#define _IN_TEMP_HI_BY_MONTHS_COL	""
#define _IN_TEMP_LO_BY_MONTHS_COL	""
#define _TEMP_HI_BY_DAYS_COL		""
#define _TEMP_HI_BY_DAYS_TIME_COL	""
#define _TEMP_LO_BY_DAYS_COL		""
#define _TEMP_LO_BY_DAYS_TIME_COL	""
#define _TEMP_HI_BY_MONTHS_COL		""
#define _TEMP_LO_BY_MONTHS_COL		""
#define _DEW_HI_BY_DAYS_COL		""
#define _DEW_HI_BY_DAYS_TIME_COL	""
#define _DEW_LO_BY_DAYS_COL		""
#define _DEW_LO_BY_DAYS_TIME_COL	""
#define _DEW_HI_BY_MONTHS_COL		""
#define _DEW_LO_BY_MONTHS_COL		""
#define _CHILL_LO_BY_DAYS_COL		""
#define _CHILL_LO_BY_DAYS_TIME_COL	""
#define _CHILL_LO_BY_MONTHS_COL		""
#define _THSW_HI_BY_DAYS_COL		""
#define _THSW_HI_BY_DAYS_TIME_COL	""
#define _THSW_HI_BY_MONTHS_COL		""
#define _HEAT_HI_BY_DAYS_COL		""
#define _HEAT_HI_BY_DAYS_TIME_COL	""
#define _HEAT_HI_BY_MONTHS_COL		""
#define _IN_HUM_HI_BY_DAYS_COL		""
#define _IN_HUM_HI_BY_DAYS_TIME_COL	""
#define _IN_HUM_LO_BY_DAYS_COL		""
#define _IN_HUM_LO_BY_DAYS_TIME_COL	""
#define _IN_HUM_HI_BY_MONTHS_COL	""
#define _IN_HUM_LO_BY_MONTHS_COL	""
#define _HUM_HI_BY_DAYS_COL		""
#define _HUM_HI_BY_DAYS_TIME_COL	""
#define _HUM_LO_BY_DAYS_COL		""
#define _HUM_LO_BY_DAYS_TIME_COL	""
#define _HUM_HI_BY_MONTHS_COL		""
#define _HUM_LO_BY_MONTHS_COL		""
#define _BAR_HI_BY_DAYS_COL		""
#define _BAR_HI_BY_DAYS_TIME_COL	""
#define _BAR_LO_BY_DAYS_COL		""
#define _BAR_LO_BY_DAYS_TIME_COL	""
#define _BAR_HI_BY_MONTHS_COL		""
#define _BAR_LO_BY_MONTHS_COL		""
#define _WIND_HI_BY_DAYS_COL		""
#define _WIND_HI_BY_DAYS_TIME_COL	""
#define _WIND_HI_DIR_BY_DAYS_COL	""
#define _WIND_HI_BY_MONTHS_COL		""
#define _WIND_HI_DIR_BY_MONTHS_COL	""
#define _WIND_HI_BY_YEARS_COL		""
#define _WIND_HI_DIR_BY_YEARS_COL	""
#define _WIND_DIR_BY_DAYS_COL		""
#define _WIND_DIR_BY_MONTHS_COL		""
#define _RAIN_RATE_BY_MINUTES_COL	""
#define _RAIN_RATE_HI_BY_DAYS_COL	""
#define _RAIN_RATE_HI_BY_DAYS_TIME_COL	""
#define _RAIN_RATE_HI_BY_MONTHS_COL	""
#define _RAIN_RATE_HI_BY_YEARS_COL	""
#define _RAIN_STORMS_COL		""
#define _RAIN_BY_DAY_COL		""
#define _RAIN_BY_MONTH_COL		""
#define _RAIN_BY_YEAR_COL		""
#define _ET_DAY_TOTAL_COL		""
#define _ET_MONTH_TOTAL_COL		""
#define _ET_YEAR_TOTAL_COL		""
#define _SOLAR_HI_BY_DAYS_COL		""
#define _SOLAR_HI_BY_DAYS_TIME_COL	""
#define _SOLAR_HI_BY_MONTHS_COL		""
#define _SOLAR_HI_BY_YEARS_COL		""
#define _UV_BY_HOUR_AVG_COL		""
#define _UV_MEDS_BY_HOURS_COL		""
#define _UV_MEDS_BY_DAYS_COL		""
#define _UV_HI_BY_DAYS_COL		""
#define _UV_HI_BY_DAYS_TIME_COL		""
#define _UV_HI_BY_MONTHS_COL		""
#define _UV_HI_BY_YEARS_COL		""
#define _LEAF_BY_HOURS_COL		""
#define _LEAF_HI_BY_DAYS_COL		""
#define _LEAF_HI_BY_DAYS_TIME_COL	""
#define _LEAF_LO_BY_DAYS_COL		""
#define _LEAF_LO_BY_DAYS_TIME_COL	""
#define _LEAF_HI_BY_MONTHS_COL		""
#define _LEAF_LO_BY_MONTHS_COL		""
#define _SOIL_BY_HOURS_COL		""
#define _SOIL_HI_BY_DAYS_COL		""
#define _SOIL_HI_BY_DAYS_TIME_COL	""
#define _SOIL_LO_BY_DAYS_COL		""
#define _SOIL_LO_BY_DAYS_TIME_COL	""
#define _SOIL_HI_BY_MONTHS_COL		""
#define _SOIL_LO_BY_MONTHS_COL		""


#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __NAMES_H__ */
