/********************************************************************************/
/*  vproweather 1.0.9                                                           */
/*	A program for acquiring data from a Davis Vantage Pro Weather Station.	*/
/*										*/
/*  Thanks to Paul Davis for his 'remserial' program, and Aaron Logue's		*/
/*  'weastat' program.								*/
/*										*/
/* (c)2004 Joe Jaworski    email: jj@joejaworski.com				*/
/* (c)2005-2013 Curt Blank email: curt@curtronics.com				*/
/* VPROWEATHER is covered under the GNU general license. See the attached	*/
/* LICENSE file for details.							*/
/*										*/
/* This software is provided as-is, without any expressed or implied		*/
/* warranties, including, without limitation, the implied warranties of		*/
/* merchantibility and fitness for any particular purpose.			*/
/*										*/
/*										*/
/* names.h - definition of output file names					*/
/*      									*/
/*	v0.6-1 cjb - grRainByHour should be grRainByHours & grRainByDay should	*/
/*		     be grRainByDays to match Time Ref				*/
/*      v0.6-2 cjb - also fix grRainByMonth should be grRainByMonths &		*/
/*		     grRainByYear should be grRainByYears			*/
/*	v0.6-3 cjb - added SOLAR stuff						*/
/*		   - added ET stuff						*/
/*		   - added THSW stuff						*/
/*      v0.6-9 cjb - modified graphic data sets-memory pointer offsets due      */
/*                   change in locations of the graph data in Vantage Pro2      */
/*                 - added UV stuff                                             */
/*                 - added LEAF stuff                                           */
/*                 - added SOIL stuff                                           */
/*     v0.7-1 cjb - we seemed to always have ignored WIND_SPEED_HOUR_HIGHS      */
/*                  (from the day of Joe) so let's add it now, no reason not to */
/*     v0.7-4 cjb - added WIND_HI_DIR_BY_DAYS                                   */
/*                - added WIND_HI_DIR_BY_MONTHS                                 */
/*                - added WIND_HI_DIR_BY_YEARS                                  */
/*                - added UV_MEDS_BY_HOURS                                      */
/*                - added UV_MEDS_BY_DAYS                                       */
/*     v0.8.0 cjb - add access to mySQL db                                      */
/*     v0.9.0 cjb - added data for handling DMP & DMPAFT                        */
/*     v0.9.9 cjb - added _??_CAPTURE_TIMESTAMP's                               */
/*     v1.0.0 cjb - added _SOLAR_NOON                                           */
/*     v1.0.9 cjb - added _EXTRA_TEMP & EXTRA_HUM                               */
/*										*/
/********************************************************************************/

#ifndef __NAMES_H__
#define __NAMES_H__

#ifdef __cplusplus
#define extern "C" {		/* respect c++ callers */
#endif

/* real time data */
#define _WIND_CHILL		"rtWindChill"
#define _HEAT_INDEX		"rtHeatIndex"
#define _BARO_TREND		"rtBaroTrend"
#define _BARO_TREND_IMG		"rtBaroTrendImg"
#define _BARO_CURR		"rtBaroCurr"
#define _INSIDE_TEMP		"rtInsideTemp"
#define _INSIDE_HUM		"rtInsideHum"
#define _OUTSIDE_TEMP		"rtOutsideTemp"
#define _WIND_SPEED		"rtWindSpeed"
#define _WIND_AVG_SPEED		"rtWindAvgSpeed"
#define _WIND_DIR		"rtWindDir"
#define _WIND_DIR_ROSE		"rtWindDirRose"
#define _EXTRA_TEMP		"rtExtraTemp"
#define _SOIL_TEMP		"rtSoilTemp"
#define _LEAF_TEMP		"rtLeafTemp"
#define _OUTSIDE_HUM		"rtOutsideHum"
#define _EXTRA_HUM		"rtExtraHum"
#define _RAIN_RATE		"rtRainRate"
#define _IS_RAINING		"rtIsRaining"
#define _UV_INDEX		"rtUVIndex"
#define _SOLAR_RAD		"rtSolarRad"
#define _RAIN_STORM		"rtRainStorm"
#define _STORM_START_DATE	"rtStormStartDate"
#define _DAY_RAIN		"rtDayRain"
#define _MONTH_RAIN		"rtMonthRain"
#define _YEAR_RAIN		"rtYearRain"
#define _DAY_ET			"rtDayET"
#define _DAY_ET_U		"rtDayEToz"
#define _DAY_ET_M		"rtDayETmL"
#define _MONTH_ET		"rtMonthET"
#define _YEAR_ET		"rtYearET"
#define _XMIT_BATT		"rtXmitBatt"
#define _BATT_VOLTAGE		"rtBattVoltage"
#define _FORE_ICON		"rtForeIcon"
#define _FORE_RULE		"rtForeRule"
#define _FORE_STRING		"rtForecast"
#define _SUNRISE		"rtSunrise"
#define _SUNSET			"rtSunset"
#define _SOLAR_NOON		"rtSolarNoon"
#define _RT_CAPTURE_TIMESTAMP   "rtCaptureTimestamp"

/* highs/lows data */
#define _BARO_LO_DAY		"hlBaroLoDay"
#define _BARO_HI_DAY		"hlBaroHiDay"
#define _BARO_LO_MONTH		"hlBaroLoMonth"
#define _BARO_HI_MONTH		"hlBaroHiMonth"
#define _BARO_LO_YEAR		"hlBaroLoYear"
#define _BARO_HI_YEAR		"hlBaroHiYear"
#define _BARO_LO_TIME		"hlBaroLoTime"
#define _BARO_HI_TIME		"hlBaroHiTime"
#define _WIND_HI_DAY		"hlWindHiDay"
#define _WIND_HI_TIME		"hlWindHiTime"
#define _WIND_HI_MONTH		"hlWindHiMonth"
#define _WIND_HI_YEAR		"hlWindHiYear"
#define _IN_TEMP_HI_DAY		"hlInTempHiDay"
#define _IN_TEMP_LO_DAY		"hlInTempLoDay"
#define _IN_TEMP_HI_TIME	"hlInTempHiTime"
#define _IN_TEMP_LO_TIME	"hlInTempLoTime"
#define _IN_TEMP_LO_MONTH	"hlInTempLoMonth"
#define _IN_TEMP_HI_MONTH	"hlInTempHiMonth"
#define _IN_TEMP_LO_YEAR	"hlInTempLoYear"
#define _IN_TEMP_HI_YEAR	"hlInTempHiYear"
#define _IN_HUM_HI_DAY		"hlInHumHiDay"
#define _IN_HUM_LO_DAY		"hlInHumLoDay"
#define _IN_HUM_HI_TIME		"hlInHumHiTime"
#define _IN_HUM_LO_TIME		"hlInHumLoTime"
#define _IN_HUM_HI_MONTH	"hlInHumHiMonth"
#define _IN_HUM_LO_MONTH	"hlInHumLoMonth"
#define _IN_HUM_HI_YEAR		"hlInHumHiYear"
#define _IN_HUM_LO_YEAR		"hlInHumLoYear"
#define _TEMP_HI_DAY		"hlOutTempHiDay"
#define _TEMP_LO_DAY		"hlOutTempLoDay"
#define _TEMP_HI_TIME		"hlOutTempHiTime"
#define _TEMP_LO_TIME		"hlOutTempLoTime"
#define _TEMP_LO_MONTH		"hlOutTempLoMonth"
#define _TEMP_HI_MONTH		"hlOutTempHiMonth"
#define _TEMP_LO_YEAR		"hlOutTempLoYear"
#define _TEMP_HI_YEAR		"hlOutTempHiYear"
#define _DEW_LO_DAY		"hlDewLoDay"
#define _DEW_HI_DAY		"hlDewHiDay"
#define _DEW_LO_TIME		"hlDewLoTime"
#define _DEW_HI_TIME		"hlDewHiTime"
#define _DEW_HI_MONTH		"hlDewHiMonth"
#define _DEW_LO_MONTH		"hlDewLoMonth"
#define _DEW_HI_YEAR		"hlDewHiYear"
#define _DEW_LO_YEAR		"hlDewLoYear"
#define _CHILL_LO_DAY		"hlChillLoDay"
#define _CHILL_LO_TIME		"hlChillLoTime"
#define _CHILL_LO_MONTH		"hlChillLoMonth"
#define _CHILL_LO_YEAR		"hlChillLoYear"
#define _HEAT_HI_DAY		"hlHeatHiDay"
#define _HEAT_HI_TIME		"hlHeatHiTime"
#define _HEAT_HI_MONTH		"hlHeatHiMonth"
#define _HEAT_HI_YEAR		"hlHeatHiYear"
#define _THSW_HI_DAY            "hlTHSWHiDay"
#define _THSW_HI_TIME           "hlTHSWHiTime"
#define _THSW_HI_MONTH          "hlTHSWHiMonth"
#define _THSW_HI_YEAR           "hlTHSWHiYear"
#define _SOLAR_HI_DAY		"hlSolarHiDay"
#define _SOLAR_HI_TIME		"hlSolarHiTime"
#define _SOLAR_HI_MONTH		"hlSolarHiMonth"
#define _SOLAR_HI_YEAR		"hlSolarHiYear"
#define _UV_HI_DAY              "hlUVHiDay"
#define _UV_HI_TIME             "hlUVHiTime"
#define _UV_HI_MONTH            "hlUVHiMonth"
#define _UV_HI_YEAR             "hlUVHiYear"
#define _RAIN_RATE_HI_DAY	"hlRainRateHiDay"
#define _RAIN_RATE_HI_TIME	"hlRainRateHiTime"
#define _RAIN_RATE_HI_HOUR	"hlRainRateHiHour"
#define _RAIN_RATE_HI_MONTH	"hlRainRateHiMonth"
#define _RAIN_RATE_HI_YEAR	"hlRainRateHiYear"
#define _HL_CAPTURE_TIMESTAMP   "hlCaptureTimestamp"


/* graph data */
#define _TIME_REF_10MIN			"grTimeRef10Min"
#define _TIME_REF_15MIN			"grTimeRef15Min"
#define _TIME_REF_HOURS			"grTimeRefHours"
#define _TIME_REF_DAYS			"grTimeRefDays"
#define _TIME_REF_MONTHS		"grTimeRefMonths"
#define	_TIME_REF_YEARS			"grTimeRefYears"
#define	_IN_TEMP_BY_HOURS		"grInTempByHours"			
#define	_IN_TEMP_HI_BY_DAYS		"grInTempHiByDays"			
#define	_IN_TEMP_HI_BY_DAYS_TIME 	"grInTempHiByDaysTime"		
#define	_IN_TEMP_LO_BY_DAYS		"grInTempLoByDays"			
#define	_IN_TEMP_LO_BY_DAYS_TIME 	"grInTempLoByDaysTime"		
#define	_IN_TEMP_HI_BY_MONTHS		"grInTempHiByMonths"			
#define	_IN_TEMP_LO_BY_MONTHS		"grInTempLoByMonths"			
#define	_TEMP_BY_HOURS			"grOutTempByHours"			
#define	_TEMP_HI_BY_DAYS		"grOutTempHiByDays"			
#define	_TEMP_HI_BY_DAYS_TIME		"grOutTempHiByDaysTime"		
#define	_TEMP_LO_BY_DAYS		"grOutTempLoByDays"			
#define	_TEMP_LO_BY_DAYS_TIME		"grOutTempLoByDaysTime"		
#define	_TEMP_HI_BY_MONTHS		"grOutTempHiByMonths"			
#define	_TEMP_LO_BY_MONTHS		"grOutTempLoByMonths"			
#define	_DEW_BY_HOURS			"grDewByHours"			
#define	_DEW_HI_BY_DAYS			"grDewHiByDays"			
#define	_DEW_HI_BY_DAYS_TIME		"grDewHiByDaysTime"		
#define	_DEW_LO_BY_DAYS			"grDewLoByDays"			
#define	_DEW_LO_BY_DAYS_TIME		"grDewLoByDaysTime"		
#define	_DEW_HI_BY_MONTHS		"grDewHiByMonths"			
#define	_DEW_LO_BY_MONTHS		"grDewLoByMonths"			
#define	_CHILL_LO_BY_HOURS		"grChillLoByHours"			
#define	_CHILL_LO_BY_DAYS		"grChillLoByDays"			
#define	_CHILL_LO_BY_DAYS_TIME		"grChillLoByDaysTime"		
#define	_CHILL_LO_BY_MONTHS		"grChillLoByMonths"			
#define _THSW_HI_BY_HOURS		"grTHSWHiByHours"
#define _THSW_HI_BY_DAYS		"grTHSWHiByDays"
#define _THSW_HI_BY_DAYS_TIME		"grTHSWHiByDaysTime"
#define _THSW_HI_BY_MONTHS		"grTHSWHiHiByMonths"
#define	_HEAT_HI_BY_HOURS		"grHeatHiByHours"			
#define	_HEAT_HI_BY_DAYS		"grHeatHiByDays"			
#define	_HEAT_HI_BY_DAYS_TIME		"grHeatHiByDaysTime"		
#define	_HEAT_HI_BY_MONTHS		"grHeatHiByMonths"			
#define	_IN_HUM_BY_HOURS		"grInHumByHours"			
#define	_IN_HUM_HI_BY_DAYS		"grInHumHiByDays"			
#define	_IN_HUM_HI_BY_DAYS_TIME		"grInHumHiByDaysTime"		
#define	_IN_HUM_LO_BY_DAYS		"grInHumLoByDays"			
#define	_IN_HUM_LO_BY_DAYS_TIME		"grInHumLoByDaysTime"		
#define	_IN_HUM_HI_BY_MONTHS		"grInHumHiByMonths"			
#define	_IN_HUM_LO_BY_MONTHS		"grInHumLoByMonths"			
#define	_HUM_BY_HOURS			"grOutHumByHours"			
#define	_HUM_HI_BY_DAYS			"grOutHumHiByDays"			
#define	_HUM_HI_BY_DAYS_TIME		"grOutHumHiByDaysTime"		
#define	_HUM_LO_BY_DAYS			"grOutHumLoByDays"			
#define	_HUM_LO_BY_DAYS_TIME		"grOutHumLoByDaysTime"		
#define	_HUM_HI_BY_MONTHS		"grOutHumHiByMonths"			
#define	_HUM_LO_BY_MONTHS		"grOutHumLoByMonths"			
#define	_BAR_BY_15MIN			"grBarBy15Min"			
#define	_BAR_BY_HOURS			"grBarByHours"			
#define	_BAR_HI_BY_DAYS			"grBarHiByDays"			
#define	_BAR_HI_BY_DAYS_TIME		"grBarHiByDaysTime"		
#define	_BAR_LO_BY_DAYS			"grBarLoByDays"			
#define	_BAR_LO_BY_DAYS_TIME		"grBarLoByDaysTime"		
#define	_BAR_HI_BY_MONTHS		"grBarHiByMonths"			
#define	_BAR_LO_BY_MONTHS		"grBarLoByMonths"			
#define	_WIND_AVG_BY_10MIN		"grWindAvgBy10Min"			
#define	_WIND_AVG_BY_HOURS		"grWindAvgByHours"			
#define _WIND_HI_BY_HOURS		"grWindHiByHours"
#define	_WIND_HI_BY_DAYS		"grWindHiByDays"			
#define	_WIND_HI_BY_DAYS_TIME		"grWindHiByDaysTime"		
#define _WIND_HI_DIR_BY_DAYS		"grWindHiDirByDays"
#define	_WIND_HI_BY_MONTHS		"grWindHiByMonths"
#define _WIND_HI_DIR_BY_MONTHS		"grWindHiDirByMonths"
#define	_WIND_HI_BY_YEARS		"grWindHiByYears"			
#define _WIND_HI_DIR_BY_YEARS		"grWindHiDirByYears"
#define	_WIND_DIR_BY_HOURS		"grWindDirByHours"			
#define	_WIND_DIR_BY_DAYS		"grWindDirByDays"			
#define	_WIND_DIR_BY_MONTHS		"grWindDirByMonths"			
#define	_RAIN_RATE_BY_MINUTES		"grRainRateByMinutes"			
#define	_RAIN_RATE_BY_HOURS		"grRainRateByHours"			
#define	_RAIN_RATE_HI_BY_DAYS		"grRainRateHiByDays"			
#define	_RAIN_RATE_HI_BY_DAYS_TIME	"grRainRateHiByDaysTime"		
#define	_RAIN_RATE_HI_BY_MONTHS		"grRainRateHiByMonths"			
#define	_RAIN_RATE_HI_BY_YEARS		"grRainRateHiByYears"			
#define	_RAIN_BY_15MIN			"grRainBy15Min"			
/* cjb to match the grTimeRef* variable names #define	_RAIN_BY_HOUR	"grRainByHour"		 */
#define  _RAIN_BY_HOUR			"grRainByHours"
#define	_RAIN_STORMS			"grRainStorms"			
#define	_RAIN_STORMS_START_DATE		"grRainStormsStartDate"			
#define	_RAIN_STORMS_END_DATE		"grRainStormsEndDate"			
/* cjb to match the grTimeRef* variable names #define	_RAIN_BY_DAY	"grRainByDay"		 */
#define      _RAIN_BY_DAY		"grRainByDays"
/* cjb #define to match the grTimeRef* variable names _RAIN_BY_MONTH	"grRainByMonth"		 */
#define  _RAIN_BY_MONTH			"grRainByMonths"
/* cjb #define to match the grTimeRef* variable names _RAIN_BY_YEAR	"grRainByYear"		 */
#define _RAIN_BY_YEAR                   "grRainByYears"
#define _ET_BY_HOUR			"grETByHours"
#define _ET_DAY_TOTAL			"grETDayTotalByDays"
#define _ET_MONTH_TOTAL			"grETMonthTotalByMonths"
#define _ET_YEAR_TOTAL			"grETYearTotalByYears"
#define _ET_U_BY_HOUR			"grETozByHours"
#define _ET_U_DAY_TOTAL			"grETozDayTotalByDays"
#define _ET_U_MONTH_TOTAL		"grETqtMonthTotalByMonths"
#define _ET_U_YEAR_TOTAL		"grETgalYearTotalByYears"
#define _ET_M_BY_HOUR			"grETmLByHours"
#define _ET_M_DAY_TOTAL			"grETmLDayTotalByDays"
#define _ET_M_MONTH_TOTAL		"grETLMonthTotalByMonths"
#define _ET_M_YEAR_TOTAL		"grETLYearTotalByYears"
#define _SOLAR_BY_HOUR_AVG		"grSolarByHourAvg"
#define _SOLAR_HI_BY_DAYS		"grSolarHiByDays"
#define _SOLAR_HI_BY_DAYS_TIME		"grSolarHiByDaysTime"
#define _SOLAR_HI_BY_MONTHS		"grSolarHiByMonths"
#define _SOLAR_HI_BY_YEARS		"grSolarHiByYears"
#define _UV_BY_HOUR_AVG                 "grUVByHourAvg"
#define _UV_MEDS_BY_HOURS		"grUVMedsByHours"
#define _UV_MEDS_BY_DAYS		"grUVMedsByDays"
#define _UV_HI_BY_DAYS                  "grUVHiByDays"
#define _UV_HI_BY_DAYS_TIME             "grUVHiByDaysTime"
#define _UV_HI_BY_MONTHS                "grUVHiByMonths"
#define _UV_HI_BY_YEARS                 "grUVHiByYears"
#define _LEAF_BY_HOURS                  "grOutLeafByHours"
#define _LEAF_HI_BY_DAYS                "grOutLeafHiByDays"
#define _LEAF_HI_BY_DAYS_TIME           "grOutLeafHiByDaysTime"
#define _LEAF_LO_BY_DAYS                "grOutLeafLoByDays"
#define _LEAF_LO_BY_DAYS_TIME           "grOutLeafLoByDaysTime"
#define _LEAF_HI_BY_MONTHS              "grOutLeafHiByMonths"
#define _LEAF_LO_BY_MONTHS              "grOutLeafLoByMonths"
#define _SOIL_BY_HOURS                  "grOutSoilByHours"
#define _SOIL_HI_BY_DAYS                "grOutSoilHiByDays"
#define _SOIL_HI_BY_DAYS_TIME           "grOutSoilHiByDaysTime"
#define _SOIL_LO_BY_DAYS                "grOutSoilLoByDays"
#define _SOIL_LO_BY_DAYS_TIME           "grOutSoilLoByDaysTime"
#define _SOIL_HI_BY_MONTHS              "grOutSoilHiByMonths"
#define _SOIL_LO_BY_MONTHS              "grOutSoilLoByMonths"
#define _GR_CAPTURE_TIMESTAMP           "grCaptureTimestamp"

/* archive data */
#define _SEQUENCE		"arSequence"
#define _DATE_STAMP		"arDate"
#define _TIME_STAMP		"arTime"
#define _TEMP_OUTSIDE		"arOutTemp"
#define _TEMP_OUT_HI		"arOutTempHi"
#define _TEMP_OUT_LO		"arOutTempLo"
#define _RAINFALL		"arRainfall"
#define _RAIN_RATE_HI		"arRainRateHi"
#define _BAROMETER		"arBaro"
#define _SOLAR_RADIATION	"arSolarRad"
#define _WIND_SAMPLES		"arWindSamples"
#define _TEMP_INSIDE		"arInTemp"
#define _HUMIDITY_INSIDE	"arInHum"
#define _HUMIDITY_OUTSIDE	"arOutHum"
#define _WIND_SPEED_AVG		"arWindAvg"
#define _WIND_SPEED_HI		"arWindHi"
#define _WIND_SPEED_HI_DIR	"arWindHiDir"
#define _WIND_DIR_PREVAIL	"arWindPrevailDir"
#define _UV_INDEX_AVG		"arUVAvg"
#define _ET			"arET"
#define _SOLAR_RADIATION_HI	"arSolarRadHi"
#define _UV_INDEX_HI		"arUVHi"
#define _FORECAST_RULE		"arForecastRuleNum"
#define _LEAF_TEMP_1		"arLeafTemp1"
#define _LEAF_TEMP_2		"arLeafTemp2"
#define _LEAF_WET_1		"arLeafWet1"
#define _LEAF_WET_2		"arLeafWet2"
#define _LEAF_WET_3		"arLeafWet3"
#define _LEAF_WET_4		"arLeafWet4"
#define _SOIL_TEMP_1		"arSoilTemp1"
#define _SOIL_TEMP_2		"arSoilTemp2"
#define _SOIL_TEMP_3		"arSoilTemp3"
#define _SOIL_TEMP_4		"arSoilTemp4"
#define _HUM_EXTRA_1		"arHumExtra1"
#define _HUM_EXTRA_2		"arHumExtra2"
#define _TEMP_EXTRA_1		"arTempExtra1"
#define _TEMP_EXTRA_2		"arTempExtra2"
#define _TEMP_EXTRA_3		"arTempExtra3"
#define _SOIL_MOIST_1		"arSoilMoist1"
#define _SOIL_MOIST_2		"arSoilMoist2"
#define _SOIL_MOIST_3		"arSoilMoist3"
#define _SOIL_MOIST_4		"arSoilMoist4"
#define _REED_OPENED		"arReedOpened"
#define _REED_CLOSED		"arReedClosed"

#ifdef __cplusplus
}
#endif /* __cplusplus */
#endif /* __NAMES_H__ */
